mocks

package
v0.12.19-alpha.39 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 23, 2026 License: Apache-2.0 Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewStore

func NewStore() (*gorm.DB, sqlmock.Sqlmock, error)

NewStore returns store mock

Types

type AuditLogger added in v0.10.0

type AuditLogger struct {
	mock.Mock
}

AuditLogger is an autogenerated mock type for the auditLogger type

func NewAuditLogger added in v0.10.0

func NewAuditLogger(t interface {
	mock.TestingT
	Cleanup(func())
}) *AuditLogger

NewAuditLogger creates a new instance of AuditLogger. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*AuditLogger) EXPECT added in v0.10.0

func (_m *AuditLogger) EXPECT() *AuditLogger_Expecter

func (*AuditLogger) Log added in v0.10.0

func (_m *AuditLogger) Log(ctx context.Context, action string, data interface{}) error

Log provides a mock function with given fields: ctx, action, data

type AuditLogger_Expecter added in v0.10.0

type AuditLogger_Expecter struct {
	// contains filtered or unexported fields
}

func (*AuditLogger_Expecter) Log added in v0.10.0

func (_e *AuditLogger_Expecter) Log(ctx interface{}, action interface{}, data interface{}) *AuditLogger_Log_Call

Log is a helper method to define mock.On call

  • ctx context.Context
  • action string
  • data interface{}

type AuditLogger_Log_Call added in v0.10.0

type AuditLogger_Log_Call struct {
	*mock.Call
}

AuditLogger_Log_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Log'

func (*AuditLogger_Log_Call) Return added in v0.10.0

func (*AuditLogger_Log_Call) Run added in v0.10.0

func (_c *AuditLogger_Log_Call) Run(run func(ctx context.Context, action string, data interface{})) *AuditLogger_Log_Call

func (*AuditLogger_Log_Call) RunAndReturn added in v0.10.0

func (_c *AuditLogger_Log_Call) RunAndReturn(run func(context.Context, string, interface{}) error) *AuditLogger_Log_Call

type Crypto

type Crypto struct {
	mock.Mock
}

Crypto is an autogenerated mock type for the Crypto type

func (*Crypto) Decrypt

func (_m *Crypto) Decrypt(_a0 string) (string, error)

Decrypt provides a mock function with given fields: _a0

func (*Crypto) EXPECT

func (_m *Crypto) EXPECT() *Crypto_Expecter

func (*Crypto) Encrypt

func (_m *Crypto) Encrypt(_a0 string) (string, error)

Encrypt provides a mock function with given fields: _a0

type Crypto_Decrypt_Call

type Crypto_Decrypt_Call struct {
	*mock.Call
}

Crypto_Decrypt_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Decrypt'

func (*Crypto_Decrypt_Call) Return

func (_c *Crypto_Decrypt_Call) Return(_a0 string, _a1 error) *Crypto_Decrypt_Call

func (*Crypto_Decrypt_Call) Run

func (_c *Crypto_Decrypt_Call) Run(run func(_a0 string)) *Crypto_Decrypt_Call

type Crypto_Encrypt_Call

type Crypto_Encrypt_Call struct {
	*mock.Call
}

Crypto_Encrypt_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Encrypt'

func (*Crypto_Encrypt_Call) Return

func (_c *Crypto_Encrypt_Call) Return(_a0 string, _a1 error) *Crypto_Encrypt_Call

func (*Crypto_Encrypt_Call) Run

func (_c *Crypto_Encrypt_Call) Run(run func(_a0 string)) *Crypto_Encrypt_Call

type Crypto_Expecter

type Crypto_Expecter struct {
	// contains filtered or unexported fields
}

func (*Crypto_Expecter) Decrypt

func (_e *Crypto_Expecter) Decrypt(_a0 interface{}) *Crypto_Decrypt_Call

Decrypt is a helper method to define mock.On call

  • _a0 string

func (*Crypto_Expecter) Encrypt

func (_e *Crypto_Expecter) Encrypt(_a0 interface{}) *Crypto_Encrypt_Call

Encrypt is a helper method to define mock.On call

  • _a0 string

type Decryptor

type Decryptor struct {
	mock.Mock
}

Decryptor is an autogenerated mock type for the Decryptor type

func (*Decryptor) Decrypt

func (_m *Decryptor) Decrypt(_a0 string) (string, error)

Decrypt provides a mock function with given fields: _a0

type Encryptor

type Encryptor struct {
	mock.Mock
}

Encryptor is an autogenerated mock type for the Encryptor type

func (*Encryptor) Encrypt

func (_m *Encryptor) Encrypt(_a0 string) (string, error)

Encrypt provides a mock function with given fields: _a0

type GrafanaClient

type GrafanaClient struct {
	mock.Mock
}

GrafanaClient is an autogenerated mock type for the GrafanaClient type

func (*GrafanaClient) GetDashboards

func (_m *GrafanaClient) GetDashboards(folderId int) ([]*grafana.Dashboard, error)

GetDashboards provides a mock function with given fields: folderId

func (*GrafanaClient) GetFolders

func (_m *GrafanaClient) GetFolders() ([]*grafana.Folder, error)

GetFolders provides a mock function with given fields:

func (*GrafanaClient) GrantDashboardAccess

func (_m *GrafanaClient) GrantDashboardAccess(resource *grafana.Dashboard, user string, role string) error

GrantDashboardAccess provides a mock function with given fields: resource, user, role

func (*GrafanaClient) RevokeDashboardAccess

func (_m *GrafanaClient) RevokeDashboardAccess(resource *grafana.Dashboard, user string, role string) error

RevokeDashboardAccess provides a mock function with given fields: resource, user, role

type HTTPClient

type HTTPClient struct {
	mock.Mock
}

HTTPClient is an autogenerated mock type for the HTTPClient type

func (*HTTPClient) Do

func (_m *HTTPClient) Do(_a0 *http.Request) (*http.Response, error)

Do provides a mock function with given fields: _a0

type IAMClient

type IAMClient struct {
	mock.Mock
}

IAMClient is an autogenerated mock type for the IAMClient type

func NewIAMClient added in v0.9.2

func NewIAMClient(t interface {
	mock.TestingT
	Cleanup(func())
}) *IAMClient

NewIAMClient creates a new instance of IAMClient. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*IAMClient) EXPECT added in v0.9.2

func (_m *IAMClient) EXPECT() *IAMClient_Expecter

func (*IAMClient) GetUser

func (_m *IAMClient) GetUser(id string) (interface{}, error)

GetUser provides a mock function with given fields: id

type IAMClient_Expecter added in v0.9.2

type IAMClient_Expecter struct {
	// contains filtered or unexported fields
}

func (*IAMClient_Expecter) GetUser added in v0.9.2

func (_e *IAMClient_Expecter) GetUser(id interface{}) *IAMClient_GetUser_Call

GetUser is a helper method to define mock.On call

  • id string

type IAMClient_GetUser_Call added in v0.9.2

type IAMClient_GetUser_Call struct {
	*mock.Call
}

IAMClient_GetUser_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetUser'

func (*IAMClient_GetUser_Call) Return added in v0.9.2

func (_c *IAMClient_GetUser_Call) Return(_a0 interface{}, _a1 error) *IAMClient_GetUser_Call

func (*IAMClient_GetUser_Call) Run added in v0.9.2

func (_c *IAMClient_GetUser_Call) Run(run func(id string)) *IAMClient_GetUser_Call

func (*IAMClient_GetUser_Call) RunAndReturn added in v0.9.2

func (_c *IAMClient_GetUser_Call) RunAndReturn(run func(string) (interface{}, error)) *IAMClient_GetUser_Call

type IAMManager

type IAMManager struct {
	mock.Mock
}

IAMManager is an autogenerated mock type for the IAMManager type

func (*IAMManager) GetClient

func (_m *IAMManager) GetClient(_a0 domain.SensitiveConfig) (domain.IAMClient, error)

GetClient provides a mock function with given fields: _a0

func (*IAMManager) ParseConfig

func (_m *IAMManager) ParseConfig(_a0 *domain.IAMConfig) (domain.SensitiveConfig, error)

ParseConfig provides a mock function with given fields: _a0

type MetabaseClient

type MetabaseClient struct {
	mock.Mock
}

MetabaseClient is an autogenerated mock type for the MetabaseClient type

func NewMetabaseClient added in v0.8.0

func NewMetabaseClient(t interface {
	mock.TestingT
	Cleanup(func())
}) *MetabaseClient

NewMetabaseClient creates a new instance of MetabaseClient. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MetabaseClient) GetCollections

func (_m *MetabaseClient) GetCollections(ctx context.Context) ([]*metabase.Collection, error)

GetCollections provides a mock function with given fields: ctx

func (*MetabaseClient) GetDatabases

func (_m *MetabaseClient) GetDatabases(ctx context.Context) ([]*metabase.Database, error)

GetDatabases provides a mock function with given fields: ctx

func (*MetabaseClient) GetGroups

GetGroups provides a mock function with given fields: ctx

func (*MetabaseClient) GrantCollectionAccess

func (_m *MetabaseClient) GrantCollectionAccess(ctx context.Context, resource *metabase.Collection, user string, role string) error

GrantCollectionAccess provides a mock function with given fields: ctx, resource, user, role

func (*MetabaseClient) GrantDatabaseAccess

func (_m *MetabaseClient) GrantDatabaseAccess(ctx context.Context, resource *metabase.Database, user string, role string, groups map[string]*metabase.Group) error

GrantDatabaseAccess provides a mock function with given fields: ctx, resource, user, role, groups

func (*MetabaseClient) GrantGroupAccess

func (_m *MetabaseClient) GrantGroupAccess(ctx context.Context, groupID int, email string) error

GrantGroupAccess provides a mock function with given fields: ctx, groupID, email

func (*MetabaseClient) GrantTableAccess

func (_m *MetabaseClient) GrantTableAccess(ctx context.Context, resource *metabase.Table, user string, role string, groups map[string]*metabase.Group) error

GrantTableAccess provides a mock function with given fields: ctx, resource, user, role, groups

func (*MetabaseClient) RevokeCollectionAccess

func (_m *MetabaseClient) RevokeCollectionAccess(ctx context.Context, resource *metabase.Collection, user string, role string) error

RevokeCollectionAccess provides a mock function with given fields: ctx, resource, user, role

func (*MetabaseClient) RevokeDatabaseAccess

func (_m *MetabaseClient) RevokeDatabaseAccess(ctx context.Context, resource *metabase.Database, user string, role string) error

RevokeDatabaseAccess provides a mock function with given fields: ctx, resource, user, role

func (*MetabaseClient) RevokeGroupAccess

func (_m *MetabaseClient) RevokeGroupAccess(ctx context.Context, groupID int, email string) error

RevokeGroupAccess provides a mock function with given fields: ctx, groupID, email

func (*MetabaseClient) RevokeTableAccess

func (_m *MetabaseClient) RevokeTableAccess(ctx context.Context, resource *metabase.Table, user string, role string) error

RevokeTableAccess provides a mock function with given fields: ctx, resource, user, role

type Notifier

type Notifier struct {
	mock.Mock
}

Notifier is an autogenerated mock type for the notifier type

func NewNotifier added in v0.10.0

func NewNotifier(t interface {
	mock.TestingT
	Cleanup(func())
}) *Notifier

NewNotifier creates a new instance of Notifier. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*Notifier) EXPECT added in v0.10.0

func (_m *Notifier) EXPECT() *Notifier_Expecter

func (*Notifier) Notify

func (_m *Notifier) Notify(_a0 context.Context, _a1 []domain.Notification) []error

Notify provides a mock function with given fields: _a0, _a1

type Notifier_Expecter added in v0.10.0

type Notifier_Expecter struct {
	// contains filtered or unexported fields
}

func (*Notifier_Expecter) Notify added in v0.10.0

func (_e *Notifier_Expecter) Notify(_a0 interface{}, _a1 interface{}) *Notifier_Notify_Call

Notify is a helper method to define mock.On call

  • _a0 context.Context
  • _a1 []domain.Notification

type Notifier_Notify_Call added in v0.10.0

type Notifier_Notify_Call struct {
	*mock.Call
}

Notifier_Notify_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Notify'

func (*Notifier_Notify_Call) Return added in v0.10.0

func (_c *Notifier_Notify_Call) Return(_a0 []error) *Notifier_Notify_Call

func (*Notifier_Notify_Call) Run added in v0.10.0

func (*Notifier_Notify_Call) RunAndReturn added in v0.10.0

type ProviderClient

type ProviderClient struct {
	mock.Mock
}

ProviderClient is an autogenerated mock type for the Client type

func (*ProviderClient) CreateConfig

func (_m *ProviderClient) CreateConfig(_a0 *domain.ProviderConfig) error

CreateConfig provides a mock function with given fields: _a0

func (*ProviderClient) GetAccountTypes

func (_m *ProviderClient) GetAccountTypes() []string

GetAccountTypes provides a mock function with given fields:

func (*ProviderClient) GetResources

func (_m *ProviderClient) GetResources(pc *domain.ProviderConfig) ([]*domain.Resource, error)

GetResources provides a mock function with given fields: pc

func (*ProviderClient) GetRoles

func (_m *ProviderClient) GetRoles(pc *domain.ProviderConfig, resourceType string) ([]*domain.Role, error)

GetRoles provides a mock function with given fields: pc, resourceType

func (*ProviderClient) GetType

func (_m *ProviderClient) GetType() string

GetType provides a mock function with given fields:

func (*ProviderClient) GrantAccess

func (_m *ProviderClient) GrantAccess(_a0 *domain.ProviderConfig, _a1 *domain.Appeal) error

GrantAccess provides a mock function with given fields: _a0, _a1

func (*ProviderClient) RevokeAccess

func (_m *ProviderClient) RevokeAccess(_a0 *domain.ProviderConfig, _a1 *domain.Appeal) error

RevokeAccess provides a mock function with given fields: _a0, _a1

type ShieldClient

type ShieldClient struct {
	mock.Mock
}

ShieldClient is an autogenerated mock type for the ShieldClient type

func NewShieldClient added in v0.8.0

func NewShieldClient(t interface {
	mock.TestingT
	Cleanup(func())
}) *ShieldClient

NewShieldClient creates a new instance of ShieldClient. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*ShieldClient) CheckUserPermission added in v0.12.17

func (_m *ShieldClient) CheckUserPermission(ctx context.Context, permissions []shield.ResourcePermission) error

CheckUserPermission provides a mock function with given fields: ctx, permissions

func (*ShieldClient) CreateTeam added in v0.12.17

func (_m *ShieldClient) CreateTeam(ctx context.Context, team shield.Group) (*shield.Group, error)

CreateTeam provides a mock function with given fields: ctx, team

func (*ShieldClient) EXPECT added in v0.12.15

func (_m *ShieldClient) EXPECT() *ShieldClient_Expecter

func (*ShieldClient) GetGroups added in v0.12.7

func (_m *ShieldClient) GetGroups(ctx context.Context) ([]*shield.Group, error)

GetGroups provides a mock function with given fields: ctx

func (*ShieldClient) GetNamespaces added in v0.12.15

func (_m *ShieldClient) GetNamespaces(ctx context.Context) ([]*shield.Namespace, error)

GetNamespaces provides a mock function with given fields: ctx

func (*ShieldClient) GetOrganizations

func (_m *ShieldClient) GetOrganizations(ctx context.Context) ([]*shield.Organization, error)

GetOrganizations provides a mock function with given fields: ctx

func (*ShieldClient) GetProjects

func (_m *ShieldClient) GetProjects(ctx context.Context) ([]*shield.Project, error)

GetProjects provides a mock function with given fields: ctx

func (*ShieldClient) GetResources added in v0.12.15

func (_m *ShieldClient) GetResources(ctx context.Context, namespace string) ([]*shield.Resource, error)

GetResources provides a mock function with given fields: ctx, namespace

func (*ShieldClient) GetSelfUser

func (_m *ShieldClient) GetSelfUser(ctx context.Context, email string) (*shield.User, error)

GetSelfUser provides a mock function with given fields: ctx, email

func (*ShieldClient) GrantCreateTeamAccess added in v0.12.17

func (_m *ShieldClient) GrantCreateTeamAccess(ctx context.Context, team shield.Group, userId string) (*shield.Group, error)

GrantCreateTeamAccess provides a mock function with given fields: ctx, team, userId

func (*ShieldClient) GrantGroupAccess added in v0.12.7

func (_m *ShieldClient) GrantGroupAccess(ctx context.Context, team *shield.Group, userId string, role string) error

GrantGroupAccess provides a mock function with given fields: ctx, team, userId, role

func (*ShieldClient) GrantOrganizationAccess

func (_m *ShieldClient) GrantOrganizationAccess(ctx context.Context, organization *shield.Organization, userId string, role string) error

GrantOrganizationAccess provides a mock function with given fields: ctx, organization, userId, role

func (*ShieldClient) GrantProjectAccess

func (_m *ShieldClient) GrantProjectAccess(ctx context.Context, project *shield.Project, userId string, role string) error

GrantProjectAccess provides a mock function with given fields: ctx, project, userId, role

func (*ShieldClient) GrantResourceAccess added in v0.12.15

func (_m *ShieldClient) GrantResourceAccess(ctx context.Context, resource *shield.Resource, userId string, role string) error

GrantResourceAccess provides a mock function with given fields: ctx, resource, userId, role

func (*ShieldClient) RevokeCreateTeamAccess added in v0.12.17

func (_m *ShieldClient) RevokeCreateTeamAccess(ctx context.Context, team shield.Group) error

RevokeCreateTeamAccess provides a mock function with given fields: ctx, team

func (*ShieldClient) RevokeGroupAccess added in v0.12.7

func (_m *ShieldClient) RevokeGroupAccess(ctx context.Context, team *shield.Group, userId string, role string) error

RevokeGroupAccess provides a mock function with given fields: ctx, team, userId, role

func (*ShieldClient) RevokeOrganizationAccess

func (_m *ShieldClient) RevokeOrganizationAccess(ctx context.Context, organization *shield.Organization, userId string, role string) error

RevokeOrganizationAccess provides a mock function with given fields: ctx, organization, userId, role

func (*ShieldClient) RevokeProjectAccess

func (_m *ShieldClient) RevokeProjectAccess(ctx context.Context, project *shield.Project, userId string, role string) error

RevokeProjectAccess provides a mock function with given fields: ctx, project, userId, role

func (*ShieldClient) RevokeResourceAccess added in v0.12.15

func (_m *ShieldClient) RevokeResourceAccess(ctx context.Context, resource *shield.Resource, userId string, role string) error

RevokeResourceAccess provides a mock function with given fields: ctx, resource, userId, role

type ShieldClient_CheckUserPermission_Call added in v0.12.17

type ShieldClient_CheckUserPermission_Call struct {
	*mock.Call
}

ShieldClient_CheckUserPermission_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'CheckUserPermission'

func (*ShieldClient_CheckUserPermission_Call) Return added in v0.12.17

func (*ShieldClient_CheckUserPermission_Call) Run added in v0.12.17

func (*ShieldClient_CheckUserPermission_Call) RunAndReturn added in v0.12.17

type ShieldClient_CreateTeam_Call added in v0.12.17

type ShieldClient_CreateTeam_Call struct {
	*mock.Call
}

ShieldClient_CreateTeam_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'CreateTeam'

func (*ShieldClient_CreateTeam_Call) Return added in v0.12.17

func (*ShieldClient_CreateTeam_Call) Run added in v0.12.17

func (*ShieldClient_CreateTeam_Call) RunAndReturn added in v0.12.17

type ShieldClient_Expecter added in v0.12.15

type ShieldClient_Expecter struct {
	// contains filtered or unexported fields
}

func (*ShieldClient_Expecter) CheckUserPermission added in v0.12.17

func (_e *ShieldClient_Expecter) CheckUserPermission(ctx interface{}, permissions interface{}) *ShieldClient_CheckUserPermission_Call

CheckUserPermission is a helper method to define mock.On call

  • ctx context.Context
  • permissions []shield.ResourcePermission

func (*ShieldClient_Expecter) CreateTeam added in v0.12.17

func (_e *ShieldClient_Expecter) CreateTeam(ctx interface{}, team interface{}) *ShieldClient_CreateTeam_Call

CreateTeam is a helper method to define mock.On call

  • ctx context.Context
  • team shield.Group

func (*ShieldClient_Expecter) GetGroups added in v0.12.15

func (_e *ShieldClient_Expecter) GetGroups(ctx interface{}) *ShieldClient_GetGroups_Call

GetGroups is a helper method to define mock.On call

  • ctx context.Context

func (*ShieldClient_Expecter) GetNamespaces added in v0.12.15

func (_e *ShieldClient_Expecter) GetNamespaces(ctx interface{}) *ShieldClient_GetNamespaces_Call

GetNamespaces is a helper method to define mock.On call

  • ctx context.Context

func (*ShieldClient_Expecter) GetOrganizations added in v0.12.15

func (_e *ShieldClient_Expecter) GetOrganizations(ctx interface{}) *ShieldClient_GetOrganizations_Call

GetOrganizations is a helper method to define mock.On call

  • ctx context.Context

func (*ShieldClient_Expecter) GetProjects added in v0.12.15

func (_e *ShieldClient_Expecter) GetProjects(ctx interface{}) *ShieldClient_GetProjects_Call

GetProjects is a helper method to define mock.On call

  • ctx context.Context

func (*ShieldClient_Expecter) GetResources added in v0.12.15

func (_e *ShieldClient_Expecter) GetResources(ctx interface{}, namespace interface{}) *ShieldClient_GetResources_Call

GetResources is a helper method to define mock.On call

  • ctx context.Context
  • namespace string

func (*ShieldClient_Expecter) GetSelfUser added in v0.12.15

func (_e *ShieldClient_Expecter) GetSelfUser(ctx interface{}, email interface{}) *ShieldClient_GetSelfUser_Call

GetSelfUser is a helper method to define mock.On call

  • ctx context.Context
  • email string

func (*ShieldClient_Expecter) GrantCreateTeamAccess added in v0.12.17

func (_e *ShieldClient_Expecter) GrantCreateTeamAccess(ctx interface{}, team interface{}, userId interface{}) *ShieldClient_GrantCreateTeamAccess_Call

GrantCreateTeamAccess is a helper method to define mock.On call

  • ctx context.Context
  • team shield.Group
  • userId string

func (*ShieldClient_Expecter) GrantGroupAccess added in v0.12.15

func (_e *ShieldClient_Expecter) GrantGroupAccess(ctx interface{}, team interface{}, userId interface{}, role interface{}) *ShieldClient_GrantGroupAccess_Call

GrantGroupAccess is a helper method to define mock.On call

  • ctx context.Context
  • team *shield.Group
  • userId string
  • role string

func (*ShieldClient_Expecter) GrantOrganizationAccess added in v0.12.15

func (_e *ShieldClient_Expecter) GrantOrganizationAccess(ctx interface{}, organization interface{}, userId interface{}, role interface{}) *ShieldClient_GrantOrganizationAccess_Call

GrantOrganizationAccess is a helper method to define mock.On call

  • ctx context.Context
  • organization *shield.Organization
  • userId string
  • role string

func (*ShieldClient_Expecter) GrantProjectAccess added in v0.12.15

func (_e *ShieldClient_Expecter) GrantProjectAccess(ctx interface{}, project interface{}, userId interface{}, role interface{}) *ShieldClient_GrantProjectAccess_Call

GrantProjectAccess is a helper method to define mock.On call

  • ctx context.Context
  • project *shield.Project
  • userId string
  • role string

func (*ShieldClient_Expecter) GrantResourceAccess added in v0.12.15

func (_e *ShieldClient_Expecter) GrantResourceAccess(ctx interface{}, resource interface{}, userId interface{}, role interface{}) *ShieldClient_GrantResourceAccess_Call

GrantResourceAccess is a helper method to define mock.On call

  • ctx context.Context
  • resource *shield.Resource
  • userId string
  • role string

func (*ShieldClient_Expecter) RevokeCreateTeamAccess added in v0.12.17

func (_e *ShieldClient_Expecter) RevokeCreateTeamAccess(ctx interface{}, team interface{}) *ShieldClient_RevokeCreateTeamAccess_Call

RevokeCreateTeamAccess is a helper method to define mock.On call

  • ctx context.Context
  • team shield.Group

func (*ShieldClient_Expecter) RevokeGroupAccess added in v0.12.15

func (_e *ShieldClient_Expecter) RevokeGroupAccess(ctx interface{}, team interface{}, userId interface{}, role interface{}) *ShieldClient_RevokeGroupAccess_Call

RevokeGroupAccess is a helper method to define mock.On call

  • ctx context.Context
  • team *shield.Group
  • userId string
  • role string

func (*ShieldClient_Expecter) RevokeOrganizationAccess added in v0.12.15

func (_e *ShieldClient_Expecter) RevokeOrganizationAccess(ctx interface{}, organization interface{}, userId interface{}, role interface{}) *ShieldClient_RevokeOrganizationAccess_Call

RevokeOrganizationAccess is a helper method to define mock.On call

  • ctx context.Context
  • organization *shield.Organization
  • userId string
  • role string

func (*ShieldClient_Expecter) RevokeProjectAccess added in v0.12.15

func (_e *ShieldClient_Expecter) RevokeProjectAccess(ctx interface{}, project interface{}, userId interface{}, role interface{}) *ShieldClient_RevokeProjectAccess_Call

RevokeProjectAccess is a helper method to define mock.On call

  • ctx context.Context
  • project *shield.Project
  • userId string
  • role string

func (*ShieldClient_Expecter) RevokeResourceAccess added in v0.12.15

func (_e *ShieldClient_Expecter) RevokeResourceAccess(ctx interface{}, resource interface{}, userId interface{}, role interface{}) *ShieldClient_RevokeResourceAccess_Call

RevokeResourceAccess is a helper method to define mock.On call

  • ctx context.Context
  • resource *shield.Resource
  • userId string
  • role string

type ShieldClient_GetGroups_Call added in v0.12.15

type ShieldClient_GetGroups_Call struct {
	*mock.Call
}

ShieldClient_GetGroups_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetGroups'

func (*ShieldClient_GetGroups_Call) Return added in v0.12.15

func (*ShieldClient_GetGroups_Call) Run added in v0.12.15

func (*ShieldClient_GetGroups_Call) RunAndReturn added in v0.12.15

type ShieldClient_GetNamespaces_Call added in v0.12.15

type ShieldClient_GetNamespaces_Call struct {
	*mock.Call
}

ShieldClient_GetNamespaces_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetNamespaces'

func (*ShieldClient_GetNamespaces_Call) Return added in v0.12.15

func (*ShieldClient_GetNamespaces_Call) Run added in v0.12.15

func (*ShieldClient_GetNamespaces_Call) RunAndReturn added in v0.12.15

type ShieldClient_GetOrganizations_Call added in v0.12.15

type ShieldClient_GetOrganizations_Call struct {
	*mock.Call
}

ShieldClient_GetOrganizations_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetOrganizations'

func (*ShieldClient_GetOrganizations_Call) Return added in v0.12.15

func (*ShieldClient_GetOrganizations_Call) Run added in v0.12.15

func (*ShieldClient_GetOrganizations_Call) RunAndReturn added in v0.12.15

type ShieldClient_GetProjects_Call added in v0.12.15

type ShieldClient_GetProjects_Call struct {
	*mock.Call
}

ShieldClient_GetProjects_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetProjects'

func (*ShieldClient_GetProjects_Call) Return added in v0.12.15

func (*ShieldClient_GetProjects_Call) Run added in v0.12.15

func (*ShieldClient_GetProjects_Call) RunAndReturn added in v0.12.15

type ShieldClient_GetResources_Call added in v0.12.15

type ShieldClient_GetResources_Call struct {
	*mock.Call
}

ShieldClient_GetResources_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetResources'

func (*ShieldClient_GetResources_Call) Return added in v0.12.15

func (*ShieldClient_GetResources_Call) Run added in v0.12.15

func (*ShieldClient_GetResources_Call) RunAndReturn added in v0.12.15

type ShieldClient_GetSelfUser_Call added in v0.12.15

type ShieldClient_GetSelfUser_Call struct {
	*mock.Call
}

ShieldClient_GetSelfUser_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetSelfUser'

func (*ShieldClient_GetSelfUser_Call) Return added in v0.12.15

func (*ShieldClient_GetSelfUser_Call) Run added in v0.12.15

func (*ShieldClient_GetSelfUser_Call) RunAndReturn added in v0.12.15

type ShieldClient_GrantCreateTeamAccess_Call added in v0.12.17

type ShieldClient_GrantCreateTeamAccess_Call struct {
	*mock.Call
}

ShieldClient_GrantCreateTeamAccess_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GrantCreateTeamAccess'

func (*ShieldClient_GrantCreateTeamAccess_Call) Return added in v0.12.17

func (*ShieldClient_GrantCreateTeamAccess_Call) Run added in v0.12.17

func (*ShieldClient_GrantCreateTeamAccess_Call) RunAndReturn added in v0.12.17

type ShieldClient_GrantGroupAccess_Call added in v0.12.15

type ShieldClient_GrantGroupAccess_Call struct {
	*mock.Call
}

ShieldClient_GrantGroupAccess_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GrantGroupAccess'

func (*ShieldClient_GrantGroupAccess_Call) Return added in v0.12.15

func (*ShieldClient_GrantGroupAccess_Call) Run added in v0.12.15

func (*ShieldClient_GrantGroupAccess_Call) RunAndReturn added in v0.12.15

type ShieldClient_GrantOrganizationAccess_Call added in v0.12.15

type ShieldClient_GrantOrganizationAccess_Call struct {
	*mock.Call
}

ShieldClient_GrantOrganizationAccess_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GrantOrganizationAccess'

func (*ShieldClient_GrantOrganizationAccess_Call) Return added in v0.12.15

func (*ShieldClient_GrantOrganizationAccess_Call) Run added in v0.12.15

func (*ShieldClient_GrantOrganizationAccess_Call) RunAndReturn added in v0.12.15

type ShieldClient_GrantProjectAccess_Call added in v0.12.15

type ShieldClient_GrantProjectAccess_Call struct {
	*mock.Call
}

ShieldClient_GrantProjectAccess_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GrantProjectAccess'

func (*ShieldClient_GrantProjectAccess_Call) Return added in v0.12.15

func (*ShieldClient_GrantProjectAccess_Call) Run added in v0.12.15

func (*ShieldClient_GrantProjectAccess_Call) RunAndReturn added in v0.12.15

type ShieldClient_GrantResourceAccess_Call added in v0.12.15

type ShieldClient_GrantResourceAccess_Call struct {
	*mock.Call
}

ShieldClient_GrantResourceAccess_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GrantResourceAccess'

func (*ShieldClient_GrantResourceAccess_Call) Return added in v0.12.15

func (*ShieldClient_GrantResourceAccess_Call) Run added in v0.12.15

func (*ShieldClient_GrantResourceAccess_Call) RunAndReturn added in v0.12.15

type ShieldClient_RevokeCreateTeamAccess_Call added in v0.12.17

type ShieldClient_RevokeCreateTeamAccess_Call struct {
	*mock.Call
}

ShieldClient_RevokeCreateTeamAccess_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'RevokeCreateTeamAccess'

func (*ShieldClient_RevokeCreateTeamAccess_Call) Return added in v0.12.17

func (*ShieldClient_RevokeCreateTeamAccess_Call) Run added in v0.12.17

func (*ShieldClient_RevokeCreateTeamAccess_Call) RunAndReturn added in v0.12.17

type ShieldClient_RevokeGroupAccess_Call added in v0.12.15

type ShieldClient_RevokeGroupAccess_Call struct {
	*mock.Call
}

ShieldClient_RevokeGroupAccess_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'RevokeGroupAccess'

func (*ShieldClient_RevokeGroupAccess_Call) Return added in v0.12.15

func (*ShieldClient_RevokeGroupAccess_Call) Run added in v0.12.15

func (*ShieldClient_RevokeGroupAccess_Call) RunAndReturn added in v0.12.15

type ShieldClient_RevokeOrganizationAccess_Call added in v0.12.15

type ShieldClient_RevokeOrganizationAccess_Call struct {
	*mock.Call
}

ShieldClient_RevokeOrganizationAccess_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'RevokeOrganizationAccess'

func (*ShieldClient_RevokeOrganizationAccess_Call) Return added in v0.12.15

func (*ShieldClient_RevokeOrganizationAccess_Call) Run added in v0.12.15

func (*ShieldClient_RevokeOrganizationAccess_Call) RunAndReturn added in v0.12.15

type ShieldClient_RevokeProjectAccess_Call added in v0.12.15

type ShieldClient_RevokeProjectAccess_Call struct {
	*mock.Call
}

ShieldClient_RevokeProjectAccess_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'RevokeProjectAccess'

func (*ShieldClient_RevokeProjectAccess_Call) Return added in v0.12.15

func (*ShieldClient_RevokeProjectAccess_Call) Run added in v0.12.15

func (*ShieldClient_RevokeProjectAccess_Call) RunAndReturn added in v0.12.15

type ShieldClient_RevokeResourceAccess_Call added in v0.12.15

type ShieldClient_RevokeResourceAccess_Call struct {
	*mock.Call
}

ShieldClient_RevokeResourceAccess_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'RevokeResourceAccess'

func (*ShieldClient_RevokeResourceAccess_Call) Return added in v0.12.15

func (*ShieldClient_RevokeResourceAccess_Call) Run added in v0.12.15

func (*ShieldClient_RevokeResourceAccess_Call) RunAndReturn added in v0.12.15

type ShieldResourceService added in v0.12.18

type ShieldResourceService struct {
	mock.Mock
}

ShieldResourceService is an autogenerated mock type for the shield.ResourceService type

func NewShieldResourceService added in v0.12.18

func NewShieldResourceService(t interface {
	mock.TestingT
	Cleanup(func())
}) *ShieldResourceService

NewShieldResourceService creates a new instance of ShieldResourceService. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*ShieldResourceService) BulkUpsert added in v0.12.18

func (_m *ShieldResourceService) BulkUpsert(_a0 context.Context, _a1 []*domain.Resource) error

BulkUpsert provides a mock function with given fields: _a0, _a1

func (*ShieldResourceService) EXPECT added in v0.12.18

type ShieldResourceService_BulkUpsert_Call added in v0.12.18

type ShieldResourceService_BulkUpsert_Call struct {
	*mock.Call
}

ShieldResourceService_BulkUpsert_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'BulkUpsert'

func (*ShieldResourceService_BulkUpsert_Call) Return added in v0.12.18

func (*ShieldResourceService_BulkUpsert_Call) Run added in v0.12.18

func (*ShieldResourceService_BulkUpsert_Call) RunAndReturn added in v0.12.18

type ShieldResourceService_Expecter added in v0.12.18

type ShieldResourceService_Expecter struct {
	// contains filtered or unexported fields
}

func (*ShieldResourceService_Expecter) BulkUpsert added in v0.12.18

func (_e *ShieldResourceService_Expecter) BulkUpsert(_a0 interface{}, _a1 interface{}) *ShieldResourceService_BulkUpsert_Call

BulkUpsert is a helper method to define mock.On call

  • _a0 context.Context
  • _a1 []*domain.Resource

type TableauClient

type TableauClient struct {
	mock.Mock
}

TableauClient is an autogenerated mock type for the TableauClient type

func (*TableauClient) GetDataSources

func (_m *TableauClient) GetDataSources() ([]*tableau.DataSource, error)

GetDataSources provides a mock function with given fields:

func (*TableauClient) GetFlows

func (_m *TableauClient) GetFlows() ([]*tableau.Flow, error)

GetFlows provides a mock function with given fields:

func (*TableauClient) GetMetrics

func (_m *TableauClient) GetMetrics() ([]*tableau.Metric, error)

GetMetrics provides a mock function with given fields:

func (*TableauClient) GetViews

func (_m *TableauClient) GetViews() ([]*tableau.View, error)

GetViews provides a mock function with given fields:

func (*TableauClient) GetWorkbooks

func (_m *TableauClient) GetWorkbooks() ([]*tableau.Workbook, error)

GetWorkbooks provides a mock function with given fields:

func (*TableauClient) GrantDataSourceAccess

func (_m *TableauClient) GrantDataSourceAccess(resource *tableau.DataSource, user string, role string) error

GrantDataSourceAccess provides a mock function with given fields: resource, user, role

func (*TableauClient) GrantFlowAccess

func (_m *TableauClient) GrantFlowAccess(resource *tableau.Flow, user string, role string) error

GrantFlowAccess provides a mock function with given fields: resource, user, role

func (*TableauClient) GrantMetricAccess

func (_m *TableauClient) GrantMetricAccess(resource *tableau.Metric, user string, role string) error

GrantMetricAccess provides a mock function with given fields: resource, user, role

func (*TableauClient) GrantViewAccess

func (_m *TableauClient) GrantViewAccess(resource *tableau.View, user string, role string) error

GrantViewAccess provides a mock function with given fields: resource, user, role

func (*TableauClient) GrantWorkbookAccess

func (_m *TableauClient) GrantWorkbookAccess(resource *tableau.Workbook, user string, role string) error

GrantWorkbookAccess provides a mock function with given fields: resource, user, role

func (*TableauClient) RevokeDataSourceAccess

func (_m *TableauClient) RevokeDataSourceAccess(resource *tableau.DataSource, user string, role string) error

RevokeDataSourceAccess provides a mock function with given fields: resource, user, role

func (*TableauClient) RevokeFlowAccess

func (_m *TableauClient) RevokeFlowAccess(resource *tableau.Flow, user string, role string) error

RevokeFlowAccess provides a mock function with given fields: resource, user, role

func (*TableauClient) RevokeMetricAccess

func (_m *TableauClient) RevokeMetricAccess(resource *tableau.Metric, user string, role string) error

RevokeMetricAccess provides a mock function with given fields: resource, user, role

func (*TableauClient) RevokeViewAccess

func (_m *TableauClient) RevokeViewAccess(resource *tableau.View, user string, role string) error

RevokeViewAccess provides a mock function with given fields: resource, user, role

func (*TableauClient) RevokeWorkbookAccess

func (_m *TableauClient) RevokeWorkbookAccess(resource *tableau.Workbook, user string, role string) error

RevokeWorkbookAccess provides a mock function with given fields: resource, user, role

func (*TableauClient) UpdateSiteRole

func (_m *TableauClient) UpdateSiteRole(user string, role string) error

UpdateSiteRole provides a mock function with given fields: user, role

Jump to