Documentation
¶
Index ¶
- func NewStore() (*gorm.DB, sqlmock.Sqlmock, error)
- type AuditLogger
- type AuditLogger_Expecter
- type AuditLogger_Log_Call
- func (_c *AuditLogger_Log_Call) Return(_a0 error) *AuditLogger_Log_Call
- func (_c *AuditLogger_Log_Call) Run(run func(ctx context.Context, action string, data interface{})) *AuditLogger_Log_Call
- func (_c *AuditLogger_Log_Call) RunAndReturn(run func(context.Context, string, interface{}) error) *AuditLogger_Log_Call
- type Crypto
- type Crypto_Decrypt_Call
- type Crypto_Encrypt_Call
- type Crypto_Expecter
- type Decryptor
- type Encryptor
- type GrafanaClient
- func (_m *GrafanaClient) GetDashboards(folderId int) ([]*grafana.Dashboard, error)
- func (_m *GrafanaClient) GetFolders() ([]*grafana.Folder, error)
- func (_m *GrafanaClient) GrantDashboardAccess(resource *grafana.Dashboard, user string, role string) error
- func (_m *GrafanaClient) RevokeDashboardAccess(resource *grafana.Dashboard, user string, role string) error
- type HTTPClient
- type IAMClient
- type IAMClient_Expecter
- type IAMClient_GetUser_Call
- type IAMManager
- type MetabaseClient
- func (_m *MetabaseClient) GetCollections(ctx context.Context) ([]*metabase.Collection, error)
- func (_m *MetabaseClient) GetDatabases(ctx context.Context) ([]*metabase.Database, error)
- func (_m *MetabaseClient) GetGroups(ctx context.Context) ([]*metabase.Group, metabase.ResourceGroupDetails, ...)
- func (_m *MetabaseClient) GrantCollectionAccess(ctx context.Context, resource *metabase.Collection, user string, role string) error
- func (_m *MetabaseClient) GrantDatabaseAccess(ctx context.Context, resource *metabase.Database, user string, role string, ...) error
- func (_m *MetabaseClient) GrantGroupAccess(ctx context.Context, groupID int, email string) error
- func (_m *MetabaseClient) GrantTableAccess(ctx context.Context, resource *metabase.Table, user string, role string, ...) error
- func (_m *MetabaseClient) RevokeCollectionAccess(ctx context.Context, resource *metabase.Collection, user string, role string) error
- func (_m *MetabaseClient) RevokeDatabaseAccess(ctx context.Context, resource *metabase.Database, user string, role string) error
- func (_m *MetabaseClient) RevokeGroupAccess(ctx context.Context, groupID int, email string) error
- func (_m *MetabaseClient) RevokeTableAccess(ctx context.Context, resource *metabase.Table, user string, role string) error
- type Notifier
- type Notifier_Expecter
- type Notifier_Notify_Call
- func (_c *Notifier_Notify_Call) Return(_a0 []error) *Notifier_Notify_Call
- func (_c *Notifier_Notify_Call) Run(run func(_a0 context.Context, _a1 []domain.Notification)) *Notifier_Notify_Call
- func (_c *Notifier_Notify_Call) RunAndReturn(run func(context.Context, []domain.Notification) []error) *Notifier_Notify_Call
- type ProviderClient
- func (_m *ProviderClient) CreateConfig(_a0 *domain.ProviderConfig) error
- func (_m *ProviderClient) GetAccountTypes() []string
- func (_m *ProviderClient) GetResources(pc *domain.ProviderConfig) ([]*domain.Resource, error)
- func (_m *ProviderClient) GetRoles(pc *domain.ProviderConfig, resourceType string) ([]*domain.Role, error)
- func (_m *ProviderClient) GetType() string
- func (_m *ProviderClient) GrantAccess(_a0 *domain.ProviderConfig, _a1 *domain.Appeal) error
- func (_m *ProviderClient) RevokeAccess(_a0 *domain.ProviderConfig, _a1 *domain.Appeal) error
- type ShieldClient
- func (_m *ShieldClient) CheckUserPermission(ctx context.Context, permissions []shield.ResourcePermission) error
- func (_m *ShieldClient) CreateTeam(ctx context.Context, team shield.Group) (*shield.Group, error)
- func (_m *ShieldClient) EXPECT() *ShieldClient_Expecter
- func (_m *ShieldClient) GetGroups(ctx context.Context) ([]*shield.Group, error)
- func (_m *ShieldClient) GetNamespaces(ctx context.Context) ([]*shield.Namespace, error)
- func (_m *ShieldClient) GetOrganizations(ctx context.Context) ([]*shield.Organization, error)
- func (_m *ShieldClient) GetProjects(ctx context.Context) ([]*shield.Project, error)
- func (_m *ShieldClient) GetResources(ctx context.Context, namespace string) ([]*shield.Resource, error)
- func (_m *ShieldClient) GetSelfUser(ctx context.Context, email string) (*shield.User, error)
- func (_m *ShieldClient) GrantCreateTeamAccess(ctx context.Context, team shield.Group, userId string) (*shield.Group, error)
- func (_m *ShieldClient) GrantGroupAccess(ctx context.Context, team *shield.Group, userId string, role string) error
- func (_m *ShieldClient) GrantOrganizationAccess(ctx context.Context, organization *shield.Organization, userId string, ...) error
- func (_m *ShieldClient) GrantProjectAccess(ctx context.Context, project *shield.Project, userId string, role string) error
- func (_m *ShieldClient) GrantResourceAccess(ctx context.Context, resource *shield.Resource, userId string, role string) error
- func (_m *ShieldClient) RevokeCreateTeamAccess(ctx context.Context, team shield.Group) error
- func (_m *ShieldClient) RevokeGroupAccess(ctx context.Context, team *shield.Group, userId string, role string) error
- func (_m *ShieldClient) RevokeOrganizationAccess(ctx context.Context, organization *shield.Organization, userId string, ...) error
- func (_m *ShieldClient) RevokeProjectAccess(ctx context.Context, project *shield.Project, userId string, role string) error
- func (_m *ShieldClient) RevokeResourceAccess(ctx context.Context, resource *shield.Resource, userId string, role string) error
- type ShieldClient_CheckUserPermission_Call
- func (_c *ShieldClient_CheckUserPermission_Call) Return(_a0 error) *ShieldClient_CheckUserPermission_Call
- func (_c *ShieldClient_CheckUserPermission_Call) Run(run func(ctx context.Context, permissions []shield.ResourcePermission)) *ShieldClient_CheckUserPermission_Call
- func (_c *ShieldClient_CheckUserPermission_Call) RunAndReturn(run func(context.Context, []shield.ResourcePermission) error) *ShieldClient_CheckUserPermission_Call
- type ShieldClient_CreateTeam_Call
- func (_c *ShieldClient_CreateTeam_Call) Return(_a0 *shield.Group, _a1 error) *ShieldClient_CreateTeam_Call
- func (_c *ShieldClient_CreateTeam_Call) Run(run func(ctx context.Context, team shield.Group)) *ShieldClient_CreateTeam_Call
- func (_c *ShieldClient_CreateTeam_Call) RunAndReturn(run func(context.Context, shield.Group) (*shield.Group, error)) *ShieldClient_CreateTeam_Call
- type ShieldClient_Expecter
- func (_e *ShieldClient_Expecter) CheckUserPermission(ctx interface{}, permissions interface{}) *ShieldClient_CheckUserPermission_Call
- func (_e *ShieldClient_Expecter) CreateTeam(ctx interface{}, team interface{}) *ShieldClient_CreateTeam_Call
- func (_e *ShieldClient_Expecter) GetGroups(ctx interface{}) *ShieldClient_GetGroups_Call
- func (_e *ShieldClient_Expecter) GetNamespaces(ctx interface{}) *ShieldClient_GetNamespaces_Call
- func (_e *ShieldClient_Expecter) GetOrganizations(ctx interface{}) *ShieldClient_GetOrganizations_Call
- func (_e *ShieldClient_Expecter) GetProjects(ctx interface{}) *ShieldClient_GetProjects_Call
- func (_e *ShieldClient_Expecter) GetResources(ctx interface{}, namespace interface{}) *ShieldClient_GetResources_Call
- func (_e *ShieldClient_Expecter) GetSelfUser(ctx interface{}, email interface{}) *ShieldClient_GetSelfUser_Call
- func (_e *ShieldClient_Expecter) GrantCreateTeamAccess(ctx interface{}, team interface{}, userId interface{}) *ShieldClient_GrantCreateTeamAccess_Call
- func (_e *ShieldClient_Expecter) GrantGroupAccess(ctx interface{}, team interface{}, userId interface{}, role interface{}) *ShieldClient_GrantGroupAccess_Call
- func (_e *ShieldClient_Expecter) GrantOrganizationAccess(ctx interface{}, organization interface{}, userId interface{}, ...) *ShieldClient_GrantOrganizationAccess_Call
- func (_e *ShieldClient_Expecter) GrantProjectAccess(ctx interface{}, project interface{}, userId interface{}, role interface{}) *ShieldClient_GrantProjectAccess_Call
- func (_e *ShieldClient_Expecter) GrantResourceAccess(ctx interface{}, resource interface{}, userId interface{}, role interface{}) *ShieldClient_GrantResourceAccess_Call
- func (_e *ShieldClient_Expecter) RevokeCreateTeamAccess(ctx interface{}, team interface{}) *ShieldClient_RevokeCreateTeamAccess_Call
- func (_e *ShieldClient_Expecter) RevokeGroupAccess(ctx interface{}, team interface{}, userId interface{}, role interface{}) *ShieldClient_RevokeGroupAccess_Call
- func (_e *ShieldClient_Expecter) RevokeOrganizationAccess(ctx interface{}, organization interface{}, userId interface{}, ...) *ShieldClient_RevokeOrganizationAccess_Call
- func (_e *ShieldClient_Expecter) RevokeProjectAccess(ctx interface{}, project interface{}, userId interface{}, role interface{}) *ShieldClient_RevokeProjectAccess_Call
- func (_e *ShieldClient_Expecter) RevokeResourceAccess(ctx interface{}, resource interface{}, userId interface{}, role interface{}) *ShieldClient_RevokeResourceAccess_Call
- type ShieldClient_GetGroups_Call
- func (_c *ShieldClient_GetGroups_Call) Return(_a0 []*shield.Group, _a1 error) *ShieldClient_GetGroups_Call
- func (_c *ShieldClient_GetGroups_Call) Run(run func(ctx context.Context)) *ShieldClient_GetGroups_Call
- func (_c *ShieldClient_GetGroups_Call) RunAndReturn(run func(context.Context) ([]*shield.Group, error)) *ShieldClient_GetGroups_Call
- type ShieldClient_GetNamespaces_Call
- func (_c *ShieldClient_GetNamespaces_Call) Return(_a0 []*shield.Namespace, _a1 error) *ShieldClient_GetNamespaces_Call
- func (_c *ShieldClient_GetNamespaces_Call) Run(run func(ctx context.Context)) *ShieldClient_GetNamespaces_Call
- func (_c *ShieldClient_GetNamespaces_Call) RunAndReturn(run func(context.Context) ([]*shield.Namespace, error)) *ShieldClient_GetNamespaces_Call
- type ShieldClient_GetOrganizations_Call
- func (_c *ShieldClient_GetOrganizations_Call) Return(_a0 []*shield.Organization, _a1 error) *ShieldClient_GetOrganizations_Call
- func (_c *ShieldClient_GetOrganizations_Call) Run(run func(ctx context.Context)) *ShieldClient_GetOrganizations_Call
- func (_c *ShieldClient_GetOrganizations_Call) RunAndReturn(run func(context.Context) ([]*shield.Organization, error)) *ShieldClient_GetOrganizations_Call
- type ShieldClient_GetProjects_Call
- func (_c *ShieldClient_GetProjects_Call) Return(_a0 []*shield.Project, _a1 error) *ShieldClient_GetProjects_Call
- func (_c *ShieldClient_GetProjects_Call) Run(run func(ctx context.Context)) *ShieldClient_GetProjects_Call
- func (_c *ShieldClient_GetProjects_Call) RunAndReturn(run func(context.Context) ([]*shield.Project, error)) *ShieldClient_GetProjects_Call
- type ShieldClient_GetResources_Call
- func (_c *ShieldClient_GetResources_Call) Return(_a0 []*shield.Resource, _a1 error) *ShieldClient_GetResources_Call
- func (_c *ShieldClient_GetResources_Call) Run(run func(ctx context.Context, namespace string)) *ShieldClient_GetResources_Call
- func (_c *ShieldClient_GetResources_Call) RunAndReturn(run func(context.Context, string) ([]*shield.Resource, error)) *ShieldClient_GetResources_Call
- type ShieldClient_GetSelfUser_Call
- func (_c *ShieldClient_GetSelfUser_Call) Return(_a0 *shield.User, _a1 error) *ShieldClient_GetSelfUser_Call
- func (_c *ShieldClient_GetSelfUser_Call) Run(run func(ctx context.Context, email string)) *ShieldClient_GetSelfUser_Call
- func (_c *ShieldClient_GetSelfUser_Call) RunAndReturn(run func(context.Context, string) (*shield.User, error)) *ShieldClient_GetSelfUser_Call
- type ShieldClient_GrantCreateTeamAccess_Call
- func (_c *ShieldClient_GrantCreateTeamAccess_Call) Return(_a0 *shield.Group, _a1 error) *ShieldClient_GrantCreateTeamAccess_Call
- func (_c *ShieldClient_GrantCreateTeamAccess_Call) Run(run func(ctx context.Context, team shield.Group, userId string)) *ShieldClient_GrantCreateTeamAccess_Call
- func (_c *ShieldClient_GrantCreateTeamAccess_Call) RunAndReturn(run func(context.Context, shield.Group, string) (*shield.Group, error)) *ShieldClient_GrantCreateTeamAccess_Call
- type ShieldClient_GrantGroupAccess_Call
- func (_c *ShieldClient_GrantGroupAccess_Call) Return(_a0 error) *ShieldClient_GrantGroupAccess_Call
- func (_c *ShieldClient_GrantGroupAccess_Call) Run(run func(ctx context.Context, team *shield.Group, userId string, role string)) *ShieldClient_GrantGroupAccess_Call
- func (_c *ShieldClient_GrantGroupAccess_Call) RunAndReturn(run func(context.Context, *shield.Group, string, string) error) *ShieldClient_GrantGroupAccess_Call
- type ShieldClient_GrantOrganizationAccess_Call
- func (_c *ShieldClient_GrantOrganizationAccess_Call) Return(_a0 error) *ShieldClient_GrantOrganizationAccess_Call
- func (_c *ShieldClient_GrantOrganizationAccess_Call) Run(...) *ShieldClient_GrantOrganizationAccess_Call
- func (_c *ShieldClient_GrantOrganizationAccess_Call) RunAndReturn(run func(context.Context, *shield.Organization, string, string) error) *ShieldClient_GrantOrganizationAccess_Call
- type ShieldClient_GrantProjectAccess_Call
- func (_c *ShieldClient_GrantProjectAccess_Call) Return(_a0 error) *ShieldClient_GrantProjectAccess_Call
- func (_c *ShieldClient_GrantProjectAccess_Call) Run(...) *ShieldClient_GrantProjectAccess_Call
- func (_c *ShieldClient_GrantProjectAccess_Call) RunAndReturn(run func(context.Context, *shield.Project, string, string) error) *ShieldClient_GrantProjectAccess_Call
- type ShieldClient_GrantResourceAccess_Call
- func (_c *ShieldClient_GrantResourceAccess_Call) Return(_a0 error) *ShieldClient_GrantResourceAccess_Call
- func (_c *ShieldClient_GrantResourceAccess_Call) Run(...) *ShieldClient_GrantResourceAccess_Call
- func (_c *ShieldClient_GrantResourceAccess_Call) RunAndReturn(run func(context.Context, *shield.Resource, string, string) error) *ShieldClient_GrantResourceAccess_Call
- type ShieldClient_RevokeCreateTeamAccess_Call
- func (_c *ShieldClient_RevokeCreateTeamAccess_Call) Return(_a0 error) *ShieldClient_RevokeCreateTeamAccess_Call
- func (_c *ShieldClient_RevokeCreateTeamAccess_Call) Run(run func(ctx context.Context, team shield.Group)) *ShieldClient_RevokeCreateTeamAccess_Call
- func (_c *ShieldClient_RevokeCreateTeamAccess_Call) RunAndReturn(run func(context.Context, shield.Group) error) *ShieldClient_RevokeCreateTeamAccess_Call
- type ShieldClient_RevokeGroupAccess_Call
- func (_c *ShieldClient_RevokeGroupAccess_Call) Return(_a0 error) *ShieldClient_RevokeGroupAccess_Call
- func (_c *ShieldClient_RevokeGroupAccess_Call) Run(run func(ctx context.Context, team *shield.Group, userId string, role string)) *ShieldClient_RevokeGroupAccess_Call
- func (_c *ShieldClient_RevokeGroupAccess_Call) RunAndReturn(run func(context.Context, *shield.Group, string, string) error) *ShieldClient_RevokeGroupAccess_Call
- type ShieldClient_RevokeOrganizationAccess_Call
- func (_c *ShieldClient_RevokeOrganizationAccess_Call) Return(_a0 error) *ShieldClient_RevokeOrganizationAccess_Call
- func (_c *ShieldClient_RevokeOrganizationAccess_Call) Run(...) *ShieldClient_RevokeOrganizationAccess_Call
- func (_c *ShieldClient_RevokeOrganizationAccess_Call) RunAndReturn(run func(context.Context, *shield.Organization, string, string) error) *ShieldClient_RevokeOrganizationAccess_Call
- type ShieldClient_RevokeProjectAccess_Call
- func (_c *ShieldClient_RevokeProjectAccess_Call) Return(_a0 error) *ShieldClient_RevokeProjectAccess_Call
- func (_c *ShieldClient_RevokeProjectAccess_Call) Run(...) *ShieldClient_RevokeProjectAccess_Call
- func (_c *ShieldClient_RevokeProjectAccess_Call) RunAndReturn(run func(context.Context, *shield.Project, string, string) error) *ShieldClient_RevokeProjectAccess_Call
- type ShieldClient_RevokeResourceAccess_Call
- func (_c *ShieldClient_RevokeResourceAccess_Call) Return(_a0 error) *ShieldClient_RevokeResourceAccess_Call
- func (_c *ShieldClient_RevokeResourceAccess_Call) Run(...) *ShieldClient_RevokeResourceAccess_Call
- func (_c *ShieldClient_RevokeResourceAccess_Call) RunAndReturn(run func(context.Context, *shield.Resource, string, string) error) *ShieldClient_RevokeResourceAccess_Call
- type ShieldResourceService
- type ShieldResourceService_BulkUpsert_Call
- func (_c *ShieldResourceService_BulkUpsert_Call) Return(_a0 error) *ShieldResourceService_BulkUpsert_Call
- func (_c *ShieldResourceService_BulkUpsert_Call) Run(run func(_a0 context.Context, _a1 []*domain.Resource)) *ShieldResourceService_BulkUpsert_Call
- func (_c *ShieldResourceService_BulkUpsert_Call) RunAndReturn(run func(context.Context, []*domain.Resource) error) *ShieldResourceService_BulkUpsert_Call
- type ShieldResourceService_Expecter
- type TableauClient
- func (_m *TableauClient) GetDataSources() ([]*tableau.DataSource, error)
- func (_m *TableauClient) GetFlows() ([]*tableau.Flow, error)
- func (_m *TableauClient) GetMetrics() ([]*tableau.Metric, error)
- func (_m *TableauClient) GetViews() ([]*tableau.View, error)
- func (_m *TableauClient) GetWorkbooks() ([]*tableau.Workbook, error)
- func (_m *TableauClient) GrantDataSourceAccess(resource *tableau.DataSource, user string, role string) error
- func (_m *TableauClient) GrantFlowAccess(resource *tableau.Flow, user string, role string) error
- func (_m *TableauClient) GrantMetricAccess(resource *tableau.Metric, user string, role string) error
- func (_m *TableauClient) GrantViewAccess(resource *tableau.View, user string, role string) error
- func (_m *TableauClient) GrantWorkbookAccess(resource *tableau.Workbook, user string, role string) error
- func (_m *TableauClient) RevokeDataSourceAccess(resource *tableau.DataSource, user string, role string) error
- func (_m *TableauClient) RevokeFlowAccess(resource *tableau.Flow, user string, role string) error
- func (_m *TableauClient) RevokeMetricAccess(resource *tableau.Metric, user string, role string) error
- func (_m *TableauClient) RevokeViewAccess(resource *tableau.View, user string, role string) error
- func (_m *TableauClient) RevokeWorkbookAccess(resource *tableau.Workbook, user string, role string) error
- func (_m *TableauClient) UpdateSiteRole(user string, role string) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type AuditLogger ¶ added in v0.10.0
AuditLogger is an autogenerated mock type for the auditLogger type
func NewAuditLogger ¶ added in v0.10.0
func NewAuditLogger(t interface {
mock.TestingT
Cleanup(func())
}) *AuditLogger
NewAuditLogger creates a new instance of AuditLogger. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*AuditLogger) EXPECT ¶ added in v0.10.0
func (_m *AuditLogger) EXPECT() *AuditLogger_Expecter
type AuditLogger_Expecter ¶ added in v0.10.0
type AuditLogger_Expecter struct {
// contains filtered or unexported fields
}
func (*AuditLogger_Expecter) Log ¶ added in v0.10.0
func (_e *AuditLogger_Expecter) Log(ctx interface{}, action interface{}, data interface{}) *AuditLogger_Log_Call
Log is a helper method to define mock.On call
- ctx context.Context
- action string
- data interface{}
type AuditLogger_Log_Call ¶ added in v0.10.0
AuditLogger_Log_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Log'
func (*AuditLogger_Log_Call) Return ¶ added in v0.10.0
func (_c *AuditLogger_Log_Call) Return(_a0 error) *AuditLogger_Log_Call
func (*AuditLogger_Log_Call) Run ¶ added in v0.10.0
func (_c *AuditLogger_Log_Call) Run(run func(ctx context.Context, action string, data interface{})) *AuditLogger_Log_Call
func (*AuditLogger_Log_Call) RunAndReturn ¶ added in v0.10.0
func (_c *AuditLogger_Log_Call) RunAndReturn(run func(context.Context, string, interface{}) error) *AuditLogger_Log_Call
type Crypto ¶
Crypto is an autogenerated mock type for the Crypto type
func (*Crypto) EXPECT ¶
func (_m *Crypto) EXPECT() *Crypto_Expecter
type Crypto_Decrypt_Call ¶
Crypto_Decrypt_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Decrypt'
func (*Crypto_Decrypt_Call) Return ¶
func (_c *Crypto_Decrypt_Call) Return(_a0 string, _a1 error) *Crypto_Decrypt_Call
func (*Crypto_Decrypt_Call) Run ¶
func (_c *Crypto_Decrypt_Call) Run(run func(_a0 string)) *Crypto_Decrypt_Call
type Crypto_Encrypt_Call ¶
Crypto_Encrypt_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Encrypt'
func (*Crypto_Encrypt_Call) Return ¶
func (_c *Crypto_Encrypt_Call) Return(_a0 string, _a1 error) *Crypto_Encrypt_Call
func (*Crypto_Encrypt_Call) Run ¶
func (_c *Crypto_Encrypt_Call) Run(run func(_a0 string)) *Crypto_Encrypt_Call
type Crypto_Expecter ¶
type Crypto_Expecter struct {
// contains filtered or unexported fields
}
func (*Crypto_Expecter) Decrypt ¶
func (_e *Crypto_Expecter) Decrypt(_a0 interface{}) *Crypto_Decrypt_Call
Decrypt is a helper method to define mock.On call
- _a0 string
func (*Crypto_Expecter) Encrypt ¶
func (_e *Crypto_Expecter) Encrypt(_a0 interface{}) *Crypto_Encrypt_Call
Encrypt is a helper method to define mock.On call
- _a0 string
type GrafanaClient ¶
GrafanaClient is an autogenerated mock type for the GrafanaClient type
func (*GrafanaClient) GetDashboards ¶
func (_m *GrafanaClient) GetDashboards(folderId int) ([]*grafana.Dashboard, error)
GetDashboards provides a mock function with given fields: folderId
func (*GrafanaClient) GetFolders ¶
func (_m *GrafanaClient) GetFolders() ([]*grafana.Folder, error)
GetFolders provides a mock function with given fields:
func (*GrafanaClient) GrantDashboardAccess ¶
func (_m *GrafanaClient) GrantDashboardAccess(resource *grafana.Dashboard, user string, role string) error
GrantDashboardAccess provides a mock function with given fields: resource, user, role
func (*GrafanaClient) RevokeDashboardAccess ¶
func (_m *GrafanaClient) RevokeDashboardAccess(resource *grafana.Dashboard, user string, role string) error
RevokeDashboardAccess provides a mock function with given fields: resource, user, role
type HTTPClient ¶
HTTPClient is an autogenerated mock type for the HTTPClient type
type IAMClient ¶
IAMClient is an autogenerated mock type for the IAMClient type
func NewIAMClient ¶ added in v0.9.2
NewIAMClient creates a new instance of IAMClient. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*IAMClient) EXPECT ¶ added in v0.9.2
func (_m *IAMClient) EXPECT() *IAMClient_Expecter
type IAMClient_Expecter ¶ added in v0.9.2
type IAMClient_Expecter struct {
// contains filtered or unexported fields
}
func (*IAMClient_Expecter) GetUser ¶ added in v0.9.2
func (_e *IAMClient_Expecter) GetUser(id interface{}) *IAMClient_GetUser_Call
GetUser is a helper method to define mock.On call
- id string
type IAMClient_GetUser_Call ¶ added in v0.9.2
IAMClient_GetUser_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetUser'
func (*IAMClient_GetUser_Call) Return ¶ added in v0.9.2
func (_c *IAMClient_GetUser_Call) Return(_a0 interface{}, _a1 error) *IAMClient_GetUser_Call
func (*IAMClient_GetUser_Call) Run ¶ added in v0.9.2
func (_c *IAMClient_GetUser_Call) Run(run func(id string)) *IAMClient_GetUser_Call
func (*IAMClient_GetUser_Call) RunAndReturn ¶ added in v0.9.2
func (_c *IAMClient_GetUser_Call) RunAndReturn(run func(string) (interface{}, error)) *IAMClient_GetUser_Call
type IAMManager ¶
IAMManager is an autogenerated mock type for the IAMManager type
func (*IAMManager) GetClient ¶
func (_m *IAMManager) GetClient(_a0 domain.SensitiveConfig) (domain.IAMClient, error)
GetClient provides a mock function with given fields: _a0
func (*IAMManager) ParseConfig ¶
func (_m *IAMManager) ParseConfig(_a0 *domain.IAMConfig) (domain.SensitiveConfig, error)
ParseConfig provides a mock function with given fields: _a0
type MetabaseClient ¶
MetabaseClient is an autogenerated mock type for the MetabaseClient type
func NewMetabaseClient ¶ added in v0.8.0
func NewMetabaseClient(t interface {
mock.TestingT
Cleanup(func())
}) *MetabaseClient
NewMetabaseClient creates a new instance of MetabaseClient. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*MetabaseClient) GetCollections ¶
func (_m *MetabaseClient) GetCollections(ctx context.Context) ([]*metabase.Collection, error)
GetCollections provides a mock function with given fields: ctx
func (*MetabaseClient) GetDatabases ¶
GetDatabases provides a mock function with given fields: ctx
func (*MetabaseClient) GetGroups ¶
func (_m *MetabaseClient) GetGroups(ctx context.Context) ([]*metabase.Group, metabase.ResourceGroupDetails, metabase.ResourceGroupDetails, error)
GetGroups provides a mock function with given fields: ctx
func (*MetabaseClient) GrantCollectionAccess ¶
func (_m *MetabaseClient) GrantCollectionAccess(ctx context.Context, resource *metabase.Collection, user string, role string) error
GrantCollectionAccess provides a mock function with given fields: ctx, resource, user, role
func (*MetabaseClient) GrantDatabaseAccess ¶
func (_m *MetabaseClient) GrantDatabaseAccess(ctx context.Context, resource *metabase.Database, user string, role string, groups map[string]*metabase.Group) error
GrantDatabaseAccess provides a mock function with given fields: ctx, resource, user, role, groups
func (*MetabaseClient) GrantGroupAccess ¶
GrantGroupAccess provides a mock function with given fields: ctx, groupID, email
func (*MetabaseClient) GrantTableAccess ¶
func (_m *MetabaseClient) GrantTableAccess(ctx context.Context, resource *metabase.Table, user string, role string, groups map[string]*metabase.Group) error
GrantTableAccess provides a mock function with given fields: ctx, resource, user, role, groups
func (*MetabaseClient) RevokeCollectionAccess ¶
func (_m *MetabaseClient) RevokeCollectionAccess(ctx context.Context, resource *metabase.Collection, user string, role string) error
RevokeCollectionAccess provides a mock function with given fields: ctx, resource, user, role
func (*MetabaseClient) RevokeDatabaseAccess ¶
func (_m *MetabaseClient) RevokeDatabaseAccess(ctx context.Context, resource *metabase.Database, user string, role string) error
RevokeDatabaseAccess provides a mock function with given fields: ctx, resource, user, role
func (*MetabaseClient) RevokeGroupAccess ¶
RevokeGroupAccess provides a mock function with given fields: ctx, groupID, email
func (*MetabaseClient) RevokeTableAccess ¶
func (_m *MetabaseClient) RevokeTableAccess(ctx context.Context, resource *metabase.Table, user string, role string) error
RevokeTableAccess provides a mock function with given fields: ctx, resource, user, role
type Notifier ¶
Notifier is an autogenerated mock type for the notifier type
func NewNotifier ¶ added in v0.10.0
NewNotifier creates a new instance of Notifier. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*Notifier) EXPECT ¶ added in v0.10.0
func (_m *Notifier) EXPECT() *Notifier_Expecter
type Notifier_Expecter ¶ added in v0.10.0
type Notifier_Expecter struct {
// contains filtered or unexported fields
}
func (*Notifier_Expecter) Notify ¶ added in v0.10.0
func (_e *Notifier_Expecter) Notify(_a0 interface{}, _a1 interface{}) *Notifier_Notify_Call
Notify is a helper method to define mock.On call
- _a0 context.Context
- _a1 []domain.Notification
type Notifier_Notify_Call ¶ added in v0.10.0
Notifier_Notify_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Notify'
func (*Notifier_Notify_Call) Return ¶ added in v0.10.0
func (_c *Notifier_Notify_Call) Return(_a0 []error) *Notifier_Notify_Call
func (*Notifier_Notify_Call) Run ¶ added in v0.10.0
func (_c *Notifier_Notify_Call) Run(run func(_a0 context.Context, _a1 []domain.Notification)) *Notifier_Notify_Call
func (*Notifier_Notify_Call) RunAndReturn ¶ added in v0.10.0
func (_c *Notifier_Notify_Call) RunAndReturn(run func(context.Context, []domain.Notification) []error) *Notifier_Notify_Call
type ProviderClient ¶
ProviderClient is an autogenerated mock type for the Client type
func (*ProviderClient) CreateConfig ¶
func (_m *ProviderClient) CreateConfig(_a0 *domain.ProviderConfig) error
CreateConfig provides a mock function with given fields: _a0
func (*ProviderClient) GetAccountTypes ¶
func (_m *ProviderClient) GetAccountTypes() []string
GetAccountTypes provides a mock function with given fields:
func (*ProviderClient) GetResources ¶
func (_m *ProviderClient) GetResources(pc *domain.ProviderConfig) ([]*domain.Resource, error)
GetResources provides a mock function with given fields: pc
func (*ProviderClient) GetRoles ¶
func (_m *ProviderClient) GetRoles(pc *domain.ProviderConfig, resourceType string) ([]*domain.Role, error)
GetRoles provides a mock function with given fields: pc, resourceType
func (*ProviderClient) GetType ¶
func (_m *ProviderClient) GetType() string
GetType provides a mock function with given fields:
func (*ProviderClient) GrantAccess ¶
func (_m *ProviderClient) GrantAccess(_a0 *domain.ProviderConfig, _a1 *domain.Appeal) error
GrantAccess provides a mock function with given fields: _a0, _a1
func (*ProviderClient) RevokeAccess ¶
func (_m *ProviderClient) RevokeAccess(_a0 *domain.ProviderConfig, _a1 *domain.Appeal) error
RevokeAccess provides a mock function with given fields: _a0, _a1
type ShieldClient ¶
ShieldClient is an autogenerated mock type for the ShieldClient type
func NewShieldClient ¶ added in v0.8.0
func NewShieldClient(t interface {
mock.TestingT
Cleanup(func())
}) *ShieldClient
NewShieldClient creates a new instance of ShieldClient. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*ShieldClient) CheckUserPermission ¶ added in v0.12.17
func (_m *ShieldClient) CheckUserPermission(ctx context.Context, permissions []shield.ResourcePermission) error
CheckUserPermission provides a mock function with given fields: ctx, permissions
func (*ShieldClient) CreateTeam ¶ added in v0.12.17
CreateTeam provides a mock function with given fields: ctx, team
func (*ShieldClient) EXPECT ¶ added in v0.12.15
func (_m *ShieldClient) EXPECT() *ShieldClient_Expecter
func (*ShieldClient) GetGroups ¶ added in v0.12.7
GetGroups provides a mock function with given fields: ctx
func (*ShieldClient) GetNamespaces ¶ added in v0.12.15
GetNamespaces provides a mock function with given fields: ctx
func (*ShieldClient) GetOrganizations ¶
func (_m *ShieldClient) GetOrganizations(ctx context.Context) ([]*shield.Organization, error)
GetOrganizations provides a mock function with given fields: ctx
func (*ShieldClient) GetProjects ¶
GetProjects provides a mock function with given fields: ctx
func (*ShieldClient) GetResources ¶ added in v0.12.15
func (_m *ShieldClient) GetResources(ctx context.Context, namespace string) ([]*shield.Resource, error)
GetResources provides a mock function with given fields: ctx, namespace
func (*ShieldClient) GetSelfUser ¶
GetSelfUser provides a mock function with given fields: ctx, email
func (*ShieldClient) GrantCreateTeamAccess ¶ added in v0.12.17
func (_m *ShieldClient) GrantCreateTeamAccess(ctx context.Context, team shield.Group, userId string) (*shield.Group, error)
GrantCreateTeamAccess provides a mock function with given fields: ctx, team, userId
func (*ShieldClient) GrantGroupAccess ¶ added in v0.12.7
func (_m *ShieldClient) GrantGroupAccess(ctx context.Context, team *shield.Group, userId string, role string) error
GrantGroupAccess provides a mock function with given fields: ctx, team, userId, role
func (*ShieldClient) GrantOrganizationAccess ¶
func (_m *ShieldClient) GrantOrganizationAccess(ctx context.Context, organization *shield.Organization, userId string, role string) error
GrantOrganizationAccess provides a mock function with given fields: ctx, organization, userId, role
func (*ShieldClient) GrantProjectAccess ¶
func (_m *ShieldClient) GrantProjectAccess(ctx context.Context, project *shield.Project, userId string, role string) error
GrantProjectAccess provides a mock function with given fields: ctx, project, userId, role
func (*ShieldClient) GrantResourceAccess ¶ added in v0.12.15
func (_m *ShieldClient) GrantResourceAccess(ctx context.Context, resource *shield.Resource, userId string, role string) error
GrantResourceAccess provides a mock function with given fields: ctx, resource, userId, role
func (*ShieldClient) RevokeCreateTeamAccess ¶ added in v0.12.17
RevokeCreateTeamAccess provides a mock function with given fields: ctx, team
func (*ShieldClient) RevokeGroupAccess ¶ added in v0.12.7
func (_m *ShieldClient) RevokeGroupAccess(ctx context.Context, team *shield.Group, userId string, role string) error
RevokeGroupAccess provides a mock function with given fields: ctx, team, userId, role
func (*ShieldClient) RevokeOrganizationAccess ¶
func (_m *ShieldClient) RevokeOrganizationAccess(ctx context.Context, organization *shield.Organization, userId string, role string) error
RevokeOrganizationAccess provides a mock function with given fields: ctx, organization, userId, role
func (*ShieldClient) RevokeProjectAccess ¶
func (_m *ShieldClient) RevokeProjectAccess(ctx context.Context, project *shield.Project, userId string, role string) error
RevokeProjectAccess provides a mock function with given fields: ctx, project, userId, role
func (*ShieldClient) RevokeResourceAccess ¶ added in v0.12.15
func (_m *ShieldClient) RevokeResourceAccess(ctx context.Context, resource *shield.Resource, userId string, role string) error
RevokeResourceAccess provides a mock function with given fields: ctx, resource, userId, role
type ShieldClient_CheckUserPermission_Call ¶ added in v0.12.17
ShieldClient_CheckUserPermission_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'CheckUserPermission'
func (*ShieldClient_CheckUserPermission_Call) Return ¶ added in v0.12.17
func (_c *ShieldClient_CheckUserPermission_Call) Return(_a0 error) *ShieldClient_CheckUserPermission_Call
func (*ShieldClient_CheckUserPermission_Call) Run ¶ added in v0.12.17
func (_c *ShieldClient_CheckUserPermission_Call) Run(run func(ctx context.Context, permissions []shield.ResourcePermission)) *ShieldClient_CheckUserPermission_Call
func (*ShieldClient_CheckUserPermission_Call) RunAndReturn ¶ added in v0.12.17
func (_c *ShieldClient_CheckUserPermission_Call) RunAndReturn(run func(context.Context, []shield.ResourcePermission) error) *ShieldClient_CheckUserPermission_Call
type ShieldClient_CreateTeam_Call ¶ added in v0.12.17
ShieldClient_CreateTeam_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'CreateTeam'
func (*ShieldClient_CreateTeam_Call) Return ¶ added in v0.12.17
func (_c *ShieldClient_CreateTeam_Call) Return(_a0 *shield.Group, _a1 error) *ShieldClient_CreateTeam_Call
func (*ShieldClient_CreateTeam_Call) Run ¶ added in v0.12.17
func (_c *ShieldClient_CreateTeam_Call) Run(run func(ctx context.Context, team shield.Group)) *ShieldClient_CreateTeam_Call
func (*ShieldClient_CreateTeam_Call) RunAndReturn ¶ added in v0.12.17
func (_c *ShieldClient_CreateTeam_Call) RunAndReturn(run func(context.Context, shield.Group) (*shield.Group, error)) *ShieldClient_CreateTeam_Call
type ShieldClient_Expecter ¶ added in v0.12.15
type ShieldClient_Expecter struct {
// contains filtered or unexported fields
}
func (*ShieldClient_Expecter) CheckUserPermission ¶ added in v0.12.17
func (_e *ShieldClient_Expecter) CheckUserPermission(ctx interface{}, permissions interface{}) *ShieldClient_CheckUserPermission_Call
CheckUserPermission is a helper method to define mock.On call
- ctx context.Context
- permissions []shield.ResourcePermission
func (*ShieldClient_Expecter) CreateTeam ¶ added in v0.12.17
func (_e *ShieldClient_Expecter) CreateTeam(ctx interface{}, team interface{}) *ShieldClient_CreateTeam_Call
CreateTeam is a helper method to define mock.On call
- ctx context.Context
- team shield.Group
func (*ShieldClient_Expecter) GetGroups ¶ added in v0.12.15
func (_e *ShieldClient_Expecter) GetGroups(ctx interface{}) *ShieldClient_GetGroups_Call
GetGroups is a helper method to define mock.On call
- ctx context.Context
func (*ShieldClient_Expecter) GetNamespaces ¶ added in v0.12.15
func (_e *ShieldClient_Expecter) GetNamespaces(ctx interface{}) *ShieldClient_GetNamespaces_Call
GetNamespaces is a helper method to define mock.On call
- ctx context.Context
func (*ShieldClient_Expecter) GetOrganizations ¶ added in v0.12.15
func (_e *ShieldClient_Expecter) GetOrganizations(ctx interface{}) *ShieldClient_GetOrganizations_Call
GetOrganizations is a helper method to define mock.On call
- ctx context.Context
func (*ShieldClient_Expecter) GetProjects ¶ added in v0.12.15
func (_e *ShieldClient_Expecter) GetProjects(ctx interface{}) *ShieldClient_GetProjects_Call
GetProjects is a helper method to define mock.On call
- ctx context.Context
func (*ShieldClient_Expecter) GetResources ¶ added in v0.12.15
func (_e *ShieldClient_Expecter) GetResources(ctx interface{}, namespace interface{}) *ShieldClient_GetResources_Call
GetResources is a helper method to define mock.On call
- ctx context.Context
- namespace string
func (*ShieldClient_Expecter) GetSelfUser ¶ added in v0.12.15
func (_e *ShieldClient_Expecter) GetSelfUser(ctx interface{}, email interface{}) *ShieldClient_GetSelfUser_Call
GetSelfUser is a helper method to define mock.On call
- ctx context.Context
- email string
func (*ShieldClient_Expecter) GrantCreateTeamAccess ¶ added in v0.12.17
func (_e *ShieldClient_Expecter) GrantCreateTeamAccess(ctx interface{}, team interface{}, userId interface{}) *ShieldClient_GrantCreateTeamAccess_Call
GrantCreateTeamAccess is a helper method to define mock.On call
- ctx context.Context
- team shield.Group
- userId string
func (*ShieldClient_Expecter) GrantGroupAccess ¶ added in v0.12.15
func (_e *ShieldClient_Expecter) GrantGroupAccess(ctx interface{}, team interface{}, userId interface{}, role interface{}) *ShieldClient_GrantGroupAccess_Call
GrantGroupAccess is a helper method to define mock.On call
- ctx context.Context
- team *shield.Group
- userId string
- role string
func (*ShieldClient_Expecter) GrantOrganizationAccess ¶ added in v0.12.15
func (_e *ShieldClient_Expecter) GrantOrganizationAccess(ctx interface{}, organization interface{}, userId interface{}, role interface{}) *ShieldClient_GrantOrganizationAccess_Call
GrantOrganizationAccess is a helper method to define mock.On call
- ctx context.Context
- organization *shield.Organization
- userId string
- role string
func (*ShieldClient_Expecter) GrantProjectAccess ¶ added in v0.12.15
func (_e *ShieldClient_Expecter) GrantProjectAccess(ctx interface{}, project interface{}, userId interface{}, role interface{}) *ShieldClient_GrantProjectAccess_Call
GrantProjectAccess is a helper method to define mock.On call
- ctx context.Context
- project *shield.Project
- userId string
- role string
func (*ShieldClient_Expecter) GrantResourceAccess ¶ added in v0.12.15
func (_e *ShieldClient_Expecter) GrantResourceAccess(ctx interface{}, resource interface{}, userId interface{}, role interface{}) *ShieldClient_GrantResourceAccess_Call
GrantResourceAccess is a helper method to define mock.On call
- ctx context.Context
- resource *shield.Resource
- userId string
- role string
func (*ShieldClient_Expecter) RevokeCreateTeamAccess ¶ added in v0.12.17
func (_e *ShieldClient_Expecter) RevokeCreateTeamAccess(ctx interface{}, team interface{}) *ShieldClient_RevokeCreateTeamAccess_Call
RevokeCreateTeamAccess is a helper method to define mock.On call
- ctx context.Context
- team shield.Group
func (*ShieldClient_Expecter) RevokeGroupAccess ¶ added in v0.12.15
func (_e *ShieldClient_Expecter) RevokeGroupAccess(ctx interface{}, team interface{}, userId interface{}, role interface{}) *ShieldClient_RevokeGroupAccess_Call
RevokeGroupAccess is a helper method to define mock.On call
- ctx context.Context
- team *shield.Group
- userId string
- role string
func (*ShieldClient_Expecter) RevokeOrganizationAccess ¶ added in v0.12.15
func (_e *ShieldClient_Expecter) RevokeOrganizationAccess(ctx interface{}, organization interface{}, userId interface{}, role interface{}) *ShieldClient_RevokeOrganizationAccess_Call
RevokeOrganizationAccess is a helper method to define mock.On call
- ctx context.Context
- organization *shield.Organization
- userId string
- role string
func (*ShieldClient_Expecter) RevokeProjectAccess ¶ added in v0.12.15
func (_e *ShieldClient_Expecter) RevokeProjectAccess(ctx interface{}, project interface{}, userId interface{}, role interface{}) *ShieldClient_RevokeProjectAccess_Call
RevokeProjectAccess is a helper method to define mock.On call
- ctx context.Context
- project *shield.Project
- userId string
- role string
func (*ShieldClient_Expecter) RevokeResourceAccess ¶ added in v0.12.15
func (_e *ShieldClient_Expecter) RevokeResourceAccess(ctx interface{}, resource interface{}, userId interface{}, role interface{}) *ShieldClient_RevokeResourceAccess_Call
RevokeResourceAccess is a helper method to define mock.On call
- ctx context.Context
- resource *shield.Resource
- userId string
- role string
type ShieldClient_GetGroups_Call ¶ added in v0.12.15
ShieldClient_GetGroups_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetGroups'
func (*ShieldClient_GetGroups_Call) Return ¶ added in v0.12.15
func (_c *ShieldClient_GetGroups_Call) Return(_a0 []*shield.Group, _a1 error) *ShieldClient_GetGroups_Call
func (*ShieldClient_GetGroups_Call) Run ¶ added in v0.12.15
func (_c *ShieldClient_GetGroups_Call) Run(run func(ctx context.Context)) *ShieldClient_GetGroups_Call
func (*ShieldClient_GetGroups_Call) RunAndReturn ¶ added in v0.12.15
func (_c *ShieldClient_GetGroups_Call) RunAndReturn(run func(context.Context) ([]*shield.Group, error)) *ShieldClient_GetGroups_Call
type ShieldClient_GetNamespaces_Call ¶ added in v0.12.15
ShieldClient_GetNamespaces_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetNamespaces'
func (*ShieldClient_GetNamespaces_Call) Return ¶ added in v0.12.15
func (_c *ShieldClient_GetNamespaces_Call) Return(_a0 []*shield.Namespace, _a1 error) *ShieldClient_GetNamespaces_Call
func (*ShieldClient_GetNamespaces_Call) Run ¶ added in v0.12.15
func (_c *ShieldClient_GetNamespaces_Call) Run(run func(ctx context.Context)) *ShieldClient_GetNamespaces_Call
func (*ShieldClient_GetNamespaces_Call) RunAndReturn ¶ added in v0.12.15
func (_c *ShieldClient_GetNamespaces_Call) RunAndReturn(run func(context.Context) ([]*shield.Namespace, error)) *ShieldClient_GetNamespaces_Call
type ShieldClient_GetOrganizations_Call ¶ added in v0.12.15
ShieldClient_GetOrganizations_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetOrganizations'
func (*ShieldClient_GetOrganizations_Call) Return ¶ added in v0.12.15
func (_c *ShieldClient_GetOrganizations_Call) Return(_a0 []*shield.Organization, _a1 error) *ShieldClient_GetOrganizations_Call
func (*ShieldClient_GetOrganizations_Call) Run ¶ added in v0.12.15
func (_c *ShieldClient_GetOrganizations_Call) Run(run func(ctx context.Context)) *ShieldClient_GetOrganizations_Call
func (*ShieldClient_GetOrganizations_Call) RunAndReturn ¶ added in v0.12.15
func (_c *ShieldClient_GetOrganizations_Call) RunAndReturn(run func(context.Context) ([]*shield.Organization, error)) *ShieldClient_GetOrganizations_Call
type ShieldClient_GetProjects_Call ¶ added in v0.12.15
ShieldClient_GetProjects_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetProjects'
func (*ShieldClient_GetProjects_Call) Return ¶ added in v0.12.15
func (_c *ShieldClient_GetProjects_Call) Return(_a0 []*shield.Project, _a1 error) *ShieldClient_GetProjects_Call
func (*ShieldClient_GetProjects_Call) Run ¶ added in v0.12.15
func (_c *ShieldClient_GetProjects_Call) Run(run func(ctx context.Context)) *ShieldClient_GetProjects_Call
func (*ShieldClient_GetProjects_Call) RunAndReturn ¶ added in v0.12.15
func (_c *ShieldClient_GetProjects_Call) RunAndReturn(run func(context.Context) ([]*shield.Project, error)) *ShieldClient_GetProjects_Call
type ShieldClient_GetResources_Call ¶ added in v0.12.15
ShieldClient_GetResources_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetResources'
func (*ShieldClient_GetResources_Call) Return ¶ added in v0.12.15
func (_c *ShieldClient_GetResources_Call) Return(_a0 []*shield.Resource, _a1 error) *ShieldClient_GetResources_Call
func (*ShieldClient_GetResources_Call) Run ¶ added in v0.12.15
func (_c *ShieldClient_GetResources_Call) Run(run func(ctx context.Context, namespace string)) *ShieldClient_GetResources_Call
func (*ShieldClient_GetResources_Call) RunAndReturn ¶ added in v0.12.15
func (_c *ShieldClient_GetResources_Call) RunAndReturn(run func(context.Context, string) ([]*shield.Resource, error)) *ShieldClient_GetResources_Call
type ShieldClient_GetSelfUser_Call ¶ added in v0.12.15
ShieldClient_GetSelfUser_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetSelfUser'
func (*ShieldClient_GetSelfUser_Call) Return ¶ added in v0.12.15
func (_c *ShieldClient_GetSelfUser_Call) Return(_a0 *shield.User, _a1 error) *ShieldClient_GetSelfUser_Call
func (*ShieldClient_GetSelfUser_Call) Run ¶ added in v0.12.15
func (_c *ShieldClient_GetSelfUser_Call) Run(run func(ctx context.Context, email string)) *ShieldClient_GetSelfUser_Call
func (*ShieldClient_GetSelfUser_Call) RunAndReturn ¶ added in v0.12.15
func (_c *ShieldClient_GetSelfUser_Call) RunAndReturn(run func(context.Context, string) (*shield.User, error)) *ShieldClient_GetSelfUser_Call
type ShieldClient_GrantCreateTeamAccess_Call ¶ added in v0.12.17
ShieldClient_GrantCreateTeamAccess_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GrantCreateTeamAccess'
func (*ShieldClient_GrantCreateTeamAccess_Call) Return ¶ added in v0.12.17
func (_c *ShieldClient_GrantCreateTeamAccess_Call) Return(_a0 *shield.Group, _a1 error) *ShieldClient_GrantCreateTeamAccess_Call
func (*ShieldClient_GrantCreateTeamAccess_Call) Run ¶ added in v0.12.17
func (_c *ShieldClient_GrantCreateTeamAccess_Call) Run(run func(ctx context.Context, team shield.Group, userId string)) *ShieldClient_GrantCreateTeamAccess_Call
func (*ShieldClient_GrantCreateTeamAccess_Call) RunAndReturn ¶ added in v0.12.17
func (_c *ShieldClient_GrantCreateTeamAccess_Call) RunAndReturn(run func(context.Context, shield.Group, string) (*shield.Group, error)) *ShieldClient_GrantCreateTeamAccess_Call
type ShieldClient_GrantGroupAccess_Call ¶ added in v0.12.15
ShieldClient_GrantGroupAccess_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GrantGroupAccess'
func (*ShieldClient_GrantGroupAccess_Call) Return ¶ added in v0.12.15
func (_c *ShieldClient_GrantGroupAccess_Call) Return(_a0 error) *ShieldClient_GrantGroupAccess_Call
func (*ShieldClient_GrantGroupAccess_Call) Run ¶ added in v0.12.15
func (_c *ShieldClient_GrantGroupAccess_Call) Run(run func(ctx context.Context, team *shield.Group, userId string, role string)) *ShieldClient_GrantGroupAccess_Call
func (*ShieldClient_GrantGroupAccess_Call) RunAndReturn ¶ added in v0.12.15
func (_c *ShieldClient_GrantGroupAccess_Call) RunAndReturn(run func(context.Context, *shield.Group, string, string) error) *ShieldClient_GrantGroupAccess_Call
type ShieldClient_GrantOrganizationAccess_Call ¶ added in v0.12.15
ShieldClient_GrantOrganizationAccess_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GrantOrganizationAccess'
func (*ShieldClient_GrantOrganizationAccess_Call) Return ¶ added in v0.12.15
func (_c *ShieldClient_GrantOrganizationAccess_Call) Return(_a0 error) *ShieldClient_GrantOrganizationAccess_Call
func (*ShieldClient_GrantOrganizationAccess_Call) Run ¶ added in v0.12.15
func (_c *ShieldClient_GrantOrganizationAccess_Call) Run(run func(ctx context.Context, organization *shield.Organization, userId string, role string)) *ShieldClient_GrantOrganizationAccess_Call
func (*ShieldClient_GrantOrganizationAccess_Call) RunAndReturn ¶ added in v0.12.15
func (_c *ShieldClient_GrantOrganizationAccess_Call) RunAndReturn(run func(context.Context, *shield.Organization, string, string) error) *ShieldClient_GrantOrganizationAccess_Call
type ShieldClient_GrantProjectAccess_Call ¶ added in v0.12.15
ShieldClient_GrantProjectAccess_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GrantProjectAccess'
func (*ShieldClient_GrantProjectAccess_Call) Return ¶ added in v0.12.15
func (_c *ShieldClient_GrantProjectAccess_Call) Return(_a0 error) *ShieldClient_GrantProjectAccess_Call
func (*ShieldClient_GrantProjectAccess_Call) Run ¶ added in v0.12.15
func (_c *ShieldClient_GrantProjectAccess_Call) Run(run func(ctx context.Context, project *shield.Project, userId string, role string)) *ShieldClient_GrantProjectAccess_Call
func (*ShieldClient_GrantProjectAccess_Call) RunAndReturn ¶ added in v0.12.15
func (_c *ShieldClient_GrantProjectAccess_Call) RunAndReturn(run func(context.Context, *shield.Project, string, string) error) *ShieldClient_GrantProjectAccess_Call
type ShieldClient_GrantResourceAccess_Call ¶ added in v0.12.15
ShieldClient_GrantResourceAccess_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GrantResourceAccess'
func (*ShieldClient_GrantResourceAccess_Call) Return ¶ added in v0.12.15
func (_c *ShieldClient_GrantResourceAccess_Call) Return(_a0 error) *ShieldClient_GrantResourceAccess_Call
func (*ShieldClient_GrantResourceAccess_Call) Run ¶ added in v0.12.15
func (_c *ShieldClient_GrantResourceAccess_Call) Run(run func(ctx context.Context, resource *shield.Resource, userId string, role string)) *ShieldClient_GrantResourceAccess_Call
func (*ShieldClient_GrantResourceAccess_Call) RunAndReturn ¶ added in v0.12.15
func (_c *ShieldClient_GrantResourceAccess_Call) RunAndReturn(run func(context.Context, *shield.Resource, string, string) error) *ShieldClient_GrantResourceAccess_Call
type ShieldClient_RevokeCreateTeamAccess_Call ¶ added in v0.12.17
ShieldClient_RevokeCreateTeamAccess_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'RevokeCreateTeamAccess'
func (*ShieldClient_RevokeCreateTeamAccess_Call) Return ¶ added in v0.12.17
func (_c *ShieldClient_RevokeCreateTeamAccess_Call) Return(_a0 error) *ShieldClient_RevokeCreateTeamAccess_Call
func (*ShieldClient_RevokeCreateTeamAccess_Call) Run ¶ added in v0.12.17
func (_c *ShieldClient_RevokeCreateTeamAccess_Call) Run(run func(ctx context.Context, team shield.Group)) *ShieldClient_RevokeCreateTeamAccess_Call
func (*ShieldClient_RevokeCreateTeamAccess_Call) RunAndReturn ¶ added in v0.12.17
func (_c *ShieldClient_RevokeCreateTeamAccess_Call) RunAndReturn(run func(context.Context, shield.Group) error) *ShieldClient_RevokeCreateTeamAccess_Call
type ShieldClient_RevokeGroupAccess_Call ¶ added in v0.12.15
ShieldClient_RevokeGroupAccess_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'RevokeGroupAccess'
func (*ShieldClient_RevokeGroupAccess_Call) Return ¶ added in v0.12.15
func (_c *ShieldClient_RevokeGroupAccess_Call) Return(_a0 error) *ShieldClient_RevokeGroupAccess_Call
func (*ShieldClient_RevokeGroupAccess_Call) Run ¶ added in v0.12.15
func (_c *ShieldClient_RevokeGroupAccess_Call) Run(run func(ctx context.Context, team *shield.Group, userId string, role string)) *ShieldClient_RevokeGroupAccess_Call
func (*ShieldClient_RevokeGroupAccess_Call) RunAndReturn ¶ added in v0.12.15
func (_c *ShieldClient_RevokeGroupAccess_Call) RunAndReturn(run func(context.Context, *shield.Group, string, string) error) *ShieldClient_RevokeGroupAccess_Call
type ShieldClient_RevokeOrganizationAccess_Call ¶ added in v0.12.15
ShieldClient_RevokeOrganizationAccess_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'RevokeOrganizationAccess'
func (*ShieldClient_RevokeOrganizationAccess_Call) Return ¶ added in v0.12.15
func (_c *ShieldClient_RevokeOrganizationAccess_Call) Return(_a0 error) *ShieldClient_RevokeOrganizationAccess_Call
func (*ShieldClient_RevokeOrganizationAccess_Call) Run ¶ added in v0.12.15
func (_c *ShieldClient_RevokeOrganizationAccess_Call) Run(run func(ctx context.Context, organization *shield.Organization, userId string, role string)) *ShieldClient_RevokeOrganizationAccess_Call
func (*ShieldClient_RevokeOrganizationAccess_Call) RunAndReturn ¶ added in v0.12.15
func (_c *ShieldClient_RevokeOrganizationAccess_Call) RunAndReturn(run func(context.Context, *shield.Organization, string, string) error) *ShieldClient_RevokeOrganizationAccess_Call
type ShieldClient_RevokeProjectAccess_Call ¶ added in v0.12.15
ShieldClient_RevokeProjectAccess_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'RevokeProjectAccess'
func (*ShieldClient_RevokeProjectAccess_Call) Return ¶ added in v0.12.15
func (_c *ShieldClient_RevokeProjectAccess_Call) Return(_a0 error) *ShieldClient_RevokeProjectAccess_Call
func (*ShieldClient_RevokeProjectAccess_Call) Run ¶ added in v0.12.15
func (_c *ShieldClient_RevokeProjectAccess_Call) Run(run func(ctx context.Context, project *shield.Project, userId string, role string)) *ShieldClient_RevokeProjectAccess_Call
func (*ShieldClient_RevokeProjectAccess_Call) RunAndReturn ¶ added in v0.12.15
func (_c *ShieldClient_RevokeProjectAccess_Call) RunAndReturn(run func(context.Context, *shield.Project, string, string) error) *ShieldClient_RevokeProjectAccess_Call
type ShieldClient_RevokeResourceAccess_Call ¶ added in v0.12.15
ShieldClient_RevokeResourceAccess_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'RevokeResourceAccess'
func (*ShieldClient_RevokeResourceAccess_Call) Return ¶ added in v0.12.15
func (_c *ShieldClient_RevokeResourceAccess_Call) Return(_a0 error) *ShieldClient_RevokeResourceAccess_Call
func (*ShieldClient_RevokeResourceAccess_Call) Run ¶ added in v0.12.15
func (_c *ShieldClient_RevokeResourceAccess_Call) Run(run func(ctx context.Context, resource *shield.Resource, userId string, role string)) *ShieldClient_RevokeResourceAccess_Call
func (*ShieldClient_RevokeResourceAccess_Call) RunAndReturn ¶ added in v0.12.15
func (_c *ShieldClient_RevokeResourceAccess_Call) RunAndReturn(run func(context.Context, *shield.Resource, string, string) error) *ShieldClient_RevokeResourceAccess_Call
type ShieldResourceService ¶ added in v0.12.18
ShieldResourceService is an autogenerated mock type for the shield.ResourceService type
func NewShieldResourceService ¶ added in v0.12.18
func NewShieldResourceService(t interface {
mock.TestingT
Cleanup(func())
}) *ShieldResourceService
NewShieldResourceService creates a new instance of ShieldResourceService. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*ShieldResourceService) BulkUpsert ¶ added in v0.12.18
BulkUpsert provides a mock function with given fields: _a0, _a1
func (*ShieldResourceService) EXPECT ¶ added in v0.12.18
func (_m *ShieldResourceService) EXPECT() *ShieldResourceService_Expecter
type ShieldResourceService_BulkUpsert_Call ¶ added in v0.12.18
ShieldResourceService_BulkUpsert_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'BulkUpsert'
func (*ShieldResourceService_BulkUpsert_Call) Return ¶ added in v0.12.18
func (_c *ShieldResourceService_BulkUpsert_Call) Return(_a0 error) *ShieldResourceService_BulkUpsert_Call
func (*ShieldResourceService_BulkUpsert_Call) Run ¶ added in v0.12.18
func (_c *ShieldResourceService_BulkUpsert_Call) Run(run func(_a0 context.Context, _a1 []*domain.Resource)) *ShieldResourceService_BulkUpsert_Call
func (*ShieldResourceService_BulkUpsert_Call) RunAndReturn ¶ added in v0.12.18
func (_c *ShieldResourceService_BulkUpsert_Call) RunAndReturn(run func(context.Context, []*domain.Resource) error) *ShieldResourceService_BulkUpsert_Call
type ShieldResourceService_Expecter ¶ added in v0.12.18
type ShieldResourceService_Expecter struct {
// contains filtered or unexported fields
}
func (*ShieldResourceService_Expecter) BulkUpsert ¶ added in v0.12.18
func (_e *ShieldResourceService_Expecter) BulkUpsert(_a0 interface{}, _a1 interface{}) *ShieldResourceService_BulkUpsert_Call
BulkUpsert is a helper method to define mock.On call
- _a0 context.Context
- _a1 []*domain.Resource
type TableauClient ¶
TableauClient is an autogenerated mock type for the TableauClient type
func (*TableauClient) GetDataSources ¶
func (_m *TableauClient) GetDataSources() ([]*tableau.DataSource, error)
GetDataSources provides a mock function with given fields:
func (*TableauClient) GetFlows ¶
func (_m *TableauClient) GetFlows() ([]*tableau.Flow, error)
GetFlows provides a mock function with given fields:
func (*TableauClient) GetMetrics ¶
func (_m *TableauClient) GetMetrics() ([]*tableau.Metric, error)
GetMetrics provides a mock function with given fields:
func (*TableauClient) GetViews ¶
func (_m *TableauClient) GetViews() ([]*tableau.View, error)
GetViews provides a mock function with given fields:
func (*TableauClient) GetWorkbooks ¶
func (_m *TableauClient) GetWorkbooks() ([]*tableau.Workbook, error)
GetWorkbooks provides a mock function with given fields:
func (*TableauClient) GrantDataSourceAccess ¶
func (_m *TableauClient) GrantDataSourceAccess(resource *tableau.DataSource, user string, role string) error
GrantDataSourceAccess provides a mock function with given fields: resource, user, role
func (*TableauClient) GrantFlowAccess ¶
GrantFlowAccess provides a mock function with given fields: resource, user, role
func (*TableauClient) GrantMetricAccess ¶
func (_m *TableauClient) GrantMetricAccess(resource *tableau.Metric, user string, role string) error
GrantMetricAccess provides a mock function with given fields: resource, user, role
func (*TableauClient) GrantViewAccess ¶
GrantViewAccess provides a mock function with given fields: resource, user, role
func (*TableauClient) GrantWorkbookAccess ¶
func (_m *TableauClient) GrantWorkbookAccess(resource *tableau.Workbook, user string, role string) error
GrantWorkbookAccess provides a mock function with given fields: resource, user, role
func (*TableauClient) RevokeDataSourceAccess ¶
func (_m *TableauClient) RevokeDataSourceAccess(resource *tableau.DataSource, user string, role string) error
RevokeDataSourceAccess provides a mock function with given fields: resource, user, role
func (*TableauClient) RevokeFlowAccess ¶
RevokeFlowAccess provides a mock function with given fields: resource, user, role
func (*TableauClient) RevokeMetricAccess ¶
func (_m *TableauClient) RevokeMetricAccess(resource *tableau.Metric, user string, role string) error
RevokeMetricAccess provides a mock function with given fields: resource, user, role
func (*TableauClient) RevokeViewAccess ¶
RevokeViewAccess provides a mock function with given fields: resource, user, role
func (*TableauClient) RevokeWorkbookAccess ¶
func (_m *TableauClient) RevokeWorkbookAccess(resource *tableau.Workbook, user string, role string) error
RevokeWorkbookAccess provides a mock function with given fields: resource, user, role
func (*TableauClient) UpdateSiteRole ¶
func (_m *TableauClient) UpdateSiteRole(user string, role string) error
UpdateSiteRole provides a mock function with given fields: user, role